"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QVariantAnimation(QAbstractAnimation):
    """
    https://doc.qt.io/qt-6/qvariantanimation.html

    **Detailed Description**

    This class is part of **The Animation Framework** . It serves as a base
    class for property and item animations, with functions for shared
    functionality.

    The class performs interpolation over **QVariant** s, but leaves using the
    interpolated values to its subclasses. Currently, Qt provides
    **QPropertyAnimation** , which animates Qt **properties** . See the
    **QPropertyAnimation**  class description if you wish to animate such
    properties.

    You can then set start and end values for the property by calling
    **setStartValue** () and **setEndValue** (), and finally call **start** ()
    to start the animation. QVariantAnimation will interpolate the property of
    the target object and emit **valueChanged** (). To react to a change in the
    current value you have to reimplement the **updateCurrentValue** () virtual
    function or connect to said signal.

    It is also possible to set values at specified steps situated between the
    start and end value. The interpolation will then touch these points at the
    specified steps. Note that the start and end values are defined as the key
    values at 0.0 and 1.0.

    There are two ways to affect how QVariantAnimation interpolates the values.
    You can set an easing curve by calling **setEasingCurve** (), and configure
    the duration by calling **setDuration** (). You can change how the
    **QVariant** s are interpolated by creating a subclass of QVariantAnimation,
    and reimplementing the virtual **interpolated** () function.

    Subclassing QVariantAnimation can be an alternative if you have **QVariant**
    s that you do not wish to declare as Qt properties. Note, however, that you
    in most cases will be better off declaring your **QVariant**  as a property.

    Not all **QVariant**  types are supported. Below is a list of currently
    supported **QVariant**  types:

    * **Int**
      * **UInt**
      * **Double**
      * **Float**
      * **QLine**
      *
    **QLineF**
      * **QPoint**
      * **QPointF**
      * **QSize**
      * **QSizeF**
    * **QRect**
      * **QRectF**
      * **QColor**

    If you need to interpolate other variant types, including custom types, you
    have to implement interpolation for these yourself. To do this, you can
    register an interpolator function for a given type. This function takes 3
    parameters: the start value, the end value, and the current progress.

    Example:

    **QVariant**  myColorInterpolator(const **QColor**  &start, const **QColor**
    &end, **qreal**  progress)
            {
                ...
                return
    **QColor** (...);
            }
            ...
    **qRegisterAnimationInterpolator** <**QColor** >(myColorInterpolator);

    Another option is to reimplement **interpolated** (), which returns
    interpolation values for the value being interpolated.

    **See also** **QPropertyAnimation** , **QAbstractAnimation** , and **The
    Animation Framework** .
    """

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#QVariantAnimation

        **QVariantAnimation::QVariantAnimation(QObject * parent = nullptr)**

        Construct a QVariantAnimation object. **parent** is passed to
        **QAbstractAnimation** 's constructor.
        """
        ...

    def interpolated(
        self, from_: typing.Any, to: typing.Any, progress: float
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#interpolated

        **[virtual protected] QVariant QVariantAnimation::interpolated(const
        QVariant & from , const QVariant & to , qreal progress ) const**

        This virtual function returns the linear interpolation between variants
        **from** and **to** , at **progress** , usually a value between 0 and 1.
        You can reimplement this function in a subclass of **QVariantAnimation**
        to provide your own interpolation algorithm.

        Note that in order for the interpolation to work with a **QEasingCurve**
        that return a value smaller than 0 or larger than 1 (such as
        **QEasingCurve::InBack** ) you should make sure that it can extrapolate.
        If the semantic of the datatype does not allow extrapolation this
        function should handle that gracefully.

        You should call the **QVariantAnimation**  implementation of this
        function if you want your class to handle the types already supported by
        Qt (see class **QVariantAnimation**  description for a list of supported
        types).

        **See also** **QEasingCurve** .
        """
        ...

    def updateCurrentValue(self, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#updateCurrentValue

        **[virtual protected] void QVariantAnimation::updateCurrentValue(const
        QVariant & value )**

        This virtual function is called every time the animation's current value
        changes. The **value** argument is the new current value.

        The base class implementation does nothing.

        **See also** **currentValue** .
        """
        ...

    def updateState(
        self, newState: QAbstractAnimation.State, oldState: QAbstractAnimation.State
    ) -> None:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#updateState

        **[override virtual protected] void
        QVariantAnimation::updateState(QAbstractAnimation::State newState ,
        QAbstractAnimation::State oldState )**

        Reimplements: **QAbstractAnimation::updateState**
        (QAbstractAnimation::State newState, QAbstractAnimation::State
        oldState).
        """
        ...

    def updateCurrentTime(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#updateCurrentTime

        **[override virtual protected] void
        QVariantAnimation::updateCurrentTime(int)**

        Reimplements: **QAbstractAnimation::updateCurrentTime** (int
        currentTime).
        """
        ...

    def event(self, event: QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#event

        **[override virtual protected] bool QVariantAnimation::event(QEvent *
        event )**

        Reimplements: **QAbstractAnimation::event** (QEvent *event).
        """
        ...

    def setEasingCurve(
        self, easing: typing.Union[QEasingCurve, QEasingCurve.Type]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#easingCurve-prop

        **[bindable] easingCurve : QEasingCurve**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the easing curve of the animation

        This property defines the easing curve of the animation. By default, a
        linear easing curve is used, resulting in linear interpolation. Other
        curves are provided, for instance, **QEasingCurve::InCirc** , which
        provides a circular entry curve. Another example is
        **QEasingCurve::InOutElastic** , which provides an elastic effect on the
        values of the interpolated variant.

        **QVariantAnimation**  will use the **QEasingCurve::valueForProgress**
        () to transform the "normalized progress" (currentTime / totalDuration)
        of the animation into the effective progress actually used by the
        animation. It is this effective progress that will be the progress when
        **interpolated** () is called. Also, the steps in the **keyValues**  are
        referring to this effective progress.

        The easing curve is used with the interpolator, the **interpolated** ()
        virtual function, and the animation's duration to control how the
        current value changes as the animation progresses.
        """
        ...

    def easingCurve(self) -> QEasingCurve:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#easingCurve-prop

        **[bindable] easingCurve : QEasingCurve**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the easing curve of the animation

        This property defines the easing curve of the animation. By default, a
        linear easing curve is used, resulting in linear interpolation. Other
        curves are provided, for instance, **QEasingCurve::InCirc** , which
        provides a circular entry curve. Another example is
        **QEasingCurve::InOutElastic** , which provides an elastic effect on the
        values of the interpolated variant.

        **QVariantAnimation**  will use the **QEasingCurve::valueForProgress**
        () to transform the "normalized progress" (currentTime / totalDuration)
        of the animation into the effective progress actually used by the
        animation. It is this effective progress that will be the progress when
        **interpolated** () is called. Also, the steps in the **keyValues**  are
        referring to this effective progress.

        The easing curve is used with the interpolator, the **interpolated** ()
        virtual function, and the animation's duration to control how the
        current value changes as the animation progresses.
        """
        ...

    def setDuration(self, msecs: int) -> None:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#duration-prop

        **[bindable] duration : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the duration of the animation

        This property describes the duration in milliseconds of the animation.
        The default duration is 250 milliseconds.

        **See also** **QAbstractAnimation::duration** ().
        """
        ...

    def duration(self) -> int:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#duration-prop

        **[bindable] duration : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the duration of the animation

        This property describes the duration in milliseconds of the animation.
        The default duration is 250 milliseconds.

        **See also** **QAbstractAnimation::duration** ().
        """
        ...

    def currentValue(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#currentValue-prop

        **[read-only] currentValue : const QVariant**

        This property holds the current value of the animation.

        This property describes the current value; an interpolated value between
        the **start value**  and the **end value** , using the current time for
        progress. The value itself is obtained from **interpolated** (), which
        is called repeatedly as the animation is running.

        **QVariantAnimation**  calls the virtual **updateCurrentValue** ()
        function when the current value changes. This is particularly useful for
        subclasses that need to track updates. For example,
        **QPropertyAnimation**  uses this function to animate Qt **properties**
        .

        **Access functions:**

        QVariant **currentValue** () const

        **Notifier signal:**

        void ****valueChanged** ** (const QVariant & **value** )

        **See also** **startValue**  and **endValue** .
        """
        ...

    def setKeyValues(
        self, values: typing.Iterable[typing.Tuple[float, typing.Any]]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#setKeyValues

        **void QVariantAnimation::setKeyValues(const
        QVariantAnimation::KeyValues & keyValues )**

        Replaces the current set of key frames with the given **keyValues**. the
        step of the key frames must be in the range 0 to 1.

        **See also** **keyValues** () and **keyValueAt** ().
        """
        ...

    def keyValues(self) -> typing.List[typing.Tuple[float, typing.Any]]:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#keyValues

        **QVariantAnimation::KeyValues QVariantAnimation::keyValues() const**

        Returns the key frames of this animation.

        **See also** **keyValueAt** () and **setKeyValues** ().
        """
        ...

    def setKeyValueAt(self, step: float, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#setKeyValueAt

        **void QVariantAnimation::setKeyValueAt(qreal step , const QVariant &
        value )**

        Creates a key frame at the given **step** with the given **value**. The
        given **step** must be in the range 0 to 1.

        **See also** **setKeyValues** () and **keyValueAt** ().
        """
        ...

    def keyValueAt(self, step: float) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#keyValueAt

        **QVariant QVariantAnimation::keyValueAt(qreal step ) const**

        Returns the key frame value for the given **step**. The given **step**
        must be in the range 0 to 1. If there is no **KeyValue**  for **step** ,
        it returns an invalid **QVariant** .

        **See also** **keyValues** () and **setKeyValueAt** ().
        """
        ...

    def setEndValue(self, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#endValue-prop

        **endValue : QVariant**

        This property holds the end value of the animation

        This property describes the end value of the animation.

        **Access functions:**

        QVariant **endValue** () const
        void **setEndValue** (const QVariant &
        **value** )

        **See also** **startValue** .
        """
        ...

    def endValue(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#endValue-prop

        **endValue : QVariant**

        This property holds the end value of the animation

        This property describes the end value of the animation.

        **Access functions:**

        QVariant **endValue** () const
        void **setEndValue** (const QVariant &
        **value** )

        **See also** **startValue** .
        """
        ...

    def setStartValue(self, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#startValue-prop

        **startValue : QVariant**

        This property holds the optional start value of the animation

        This property describes the optional start value of the animation. If
        omitted, or if a null **QVariant**  is assigned as the start value, the
        animation will use the current position of the end when the animation is
        started.

        **Access functions:**

        QVariant **startValue** () const
        void **setStartValue** (const
        QVariant & **value** )

        **See also** **endValue** .

        **Member Function Documentation**
        """
        ...

    def startValue(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#startValue-prop

        **startValue : QVariant**

        This property holds the optional start value of the animation

        This property describes the optional start value of the animation. If
        omitted, or if a null **QVariant**  is assigned as the start value, the
        animation will use the current position of the end when the animation is
        started.

        **Access functions:**

        QVariant **startValue** () const
        void **setStartValue** (const
        QVariant & **value** )

        **See also** **endValue** .

        **Member Function Documentation**
        """
        ...

    @property
    def valueChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qvariantanimation.html#valueChanged

        **[signal] void QVariantAnimation::valueChanged(const QVariant & value
        )**

        **QVariantAnimation**  emits this signal whenever the current **value**
        changes.

        **Note:** Notifier signal for property **currentValue** .

        **See also** **currentValue** , **startValue** , and **endValue** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QSystemTrayIcon(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qsystemtrayicon.html

    **Detailed Description**

    Modern operating systems usually provide a special area on the desktop,
    called the **system tray** or **notification area** , where long-running
    applications can display icons and short messages.

    ![The system tray on Windows XP.](images/system-tray.png)

    The QSystemTrayIcon class can be used on the following platforms:

    * All supported versions of Windows.
      * All window managers and independent
    tray implementations for X11 that implement the
    **http://standards.freedesktop.org/systemtray-spec/systemtray-spec-0.2.html
    freedesktop.org**  XEmbed system tray specification.
      * All X11 desktop
    environments that implement the D-Bus <http://www.freedesktop.org/wiki/Speci
    fications/StatusNotifierItem/StatusNotifierItem> specification, including
    recent versions of KDE and Unity.
      * All supported versions of macOS.

    To check whether a system tray is present on the user's desktop, call the
    **QSystemTrayIcon::isSystemTrayAvailable** () static function.

    To add a system tray entry, create a QSystemTrayIcon object, call
    **setContextMenu** () to provide a context menu for the icon, and call
    **show** () to make it visible in the system tray. Status notification
    messages ("balloon messages") can be displayed at any time using
    **showMessage** ().

    If the system tray is unavailable when a system tray icon is constructed,
    but becomes available later, QSystemTrayIcon will automatically add an entry
    for the application in the system tray if the icon is **visible** .

    The **activated** () signal is emitted when the user activates the icon.

    Only on X11, when a tooltip is requested, the QSystemTrayIcon receives a
    **QHelpEvent**  of type **QEvent::ToolTip** . Additionally, the
    QSystemTrayIcon receives wheel events of type **QEvent::Wheel** . These are
    not supported on any other platform.

    **See also** **QDesktopServices** , **Desktop Integration** , and **System
    Tray Icon Example** .
    """

    class MessageIcon(enum.Enum):
        NoIcon: QSystemTrayIcon = ...
        Information: QSystemTrayIcon = ...
        Warning: QSystemTrayIcon = ...
        Critical: QSystemTrayIcon = ...

    class ActivationReason(enum.Enum):
        Unknown: QSystemTrayIcon = ...
        Context: QSystemTrayIcon = ...
        DoubleClick: QSystemTrayIcon = ...
        Trigger: QSystemTrayIcon = ...
        MiddleClick: QSystemTrayIcon = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#QSystemTrayIcon

        **QSystemTrayIcon::QSystemTrayIcon(QObject * parent = nullptr)**

        Constructs a QSystemTrayIcon object with the given **parent**.

        The icon is initially invisible.

        **See also** **visible** .
        """
        ...

    @typing.overload
    def __init__(
        self, icon: QtGui.QIcon, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#QSystemTrayIcon-1

        **QSystemTrayIcon::QSystemTrayIcon(const QIcon & icon , QObject * parent
        = nullptr)**

        Constructs a QSystemTrayIcon object with the given **icon** and
        **parent**.

        The icon is initially invisible.

        **See also** **visible** .
        """
        ...

    def event(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#event

        **[override virtual protected] bool QSystemTrayIcon::event(QEvent * e
        )**

        Reimplements: **QObject::event** (QEvent *e).
        """
        ...

    def show(self) -> None:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#show

        **[slot] void QSystemTrayIcon::show()**

        Shows the icon in the system tray.

        **See also** **hide** () and **visible** .
        """
        ...

    def setVisible(self, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#visible-prop

        **visible : bool**

        This property holds whether the system tray entry is visible

        Setting this property to true or calling **show** () makes the system
        tray icon visible; setting this property to false or calling **hide** ()
        hides it.

        **Access functions:**

        bool **isVisible** () const
        void **setVisible** (bool **visible** )

        **Member Function Documentation**
        """
        ...

    def hide(self) -> None:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#hide

        **[slot] void QSystemTrayIcon::hide()**

        Hides the system tray entry.

        **See also** **show** () and **visible** .
        """
        ...

    def isVisible(self) -> bool:
        ...

    @typing.overload
    def showMessage(
        self,
        title: str,
        msg: str,
        icon: "QSystemTrayIcon.MessageIcon" = ...,
        msecs: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#showMessage

        **[slot] void QSystemTrayIcon::showMessage(const QString & title , const
        QString & message , QSystemTrayIcon::MessageIcon icon =
        QSystemTrayIcon::Information, int millisecondsTimeoutHint = 10000)**

        Shows a balloon message for the entry with the given **title** ,
        **message** and **icon** for the time specified in
        **millisecondsTimeoutHint**. **title** and **message** must be plain
        text strings.

        Message can be clicked by the user; the **messageClicked** () signal
        will emitted when this occurs.

        Note that display of messages are dependent on the system configuration
        and user preferences, and that messages may not appear at all. Hence, it
        should not be relied upon as the sole means for providing critical
        information.

        On Windows, the **millisecondsTimeoutHint** is usually ignored by the
        system when the application has focus.

        Has been turned into a slot in Qt 5.2.

        **See also** **show** () and **supportsMessages** ().
        """
        ...

    @typing.overload
    def showMessage(
        self, title: str, msg: str, icon: QtGui.QIcon, msecs: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#showMessage-1

        **[slot, since 5.9] void QSystemTrayIcon::showMessage(const QString &
        title , const QString & message , const QIcon & icon , int
        millisecondsTimeoutHint = 10000)**

        This function overloads showMessage().

        Shows a balloon message for the entry with the given **title** ,
        **message** , and custom icon **icon** for the time specified in
        **millisecondsTimeoutHint**.

        This function was introduced in Qt 5.9.
        """
        ...

    @staticmethod
    def supportsMessages() -> bool:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#supportsMessages

        **[static] bool QSystemTrayIcon::supportsMessages()**

        Returns `true` if the system tray supports balloon messages; otherwise
        returns `false`.

        **See also** **showMessage** ().
        """
        ...

    @staticmethod
    def isSystemTrayAvailable() -> bool:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#isSystemTrayAvailable

        **[static] bool QSystemTrayIcon::isSystemTrayAvailable()**

        Returns `true` if the system tray is available; otherwise returns
        `false`.

        If the system tray is currently unavailable but becomes available later,
        **QSystemTrayIcon**  will automatically add an entry in the system tray
        if it is **visible** .
        """
        ...

    def setToolTip(self, tip: str) -> None:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#toolTip-prop

        **toolTip : QString**

        This property holds the tooltip for the system tray entry

        On some systems, the tooltip's length is limited. The tooltip will be
        truncated if necessary.

        **Access functions:**

        QString **toolTip** () const
        void **setToolTip** (const QString &
        **tip** )
        """
        ...

    def toolTip(self) -> str:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#toolTip-prop

        **toolTip : QString**

        This property holds the tooltip for the system tray entry

        On some systems, the tooltip's length is limited. The tooltip will be
        truncated if necessary.

        **Access functions:**

        QString **toolTip** () const
        void **setToolTip** (const QString &
        **tip** )
        """
        ...

    def setIcon(self, icon: QtGui.QIcon) -> None:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#icon-prop

        **icon : QIcon**

        This property holds the system tray icon

        On Windows, the system tray icon size is 16x16; on X11, the preferred
        size is 22x22. The icon will be scaled to the appropriate size as
        necessary.

        **Access functions:**

        QIcon **icon** () const
        void **setIcon** (const QIcon & **icon** )
        """
        ...

    def icon(self) -> QtGui.QIcon:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#icon-prop

        **icon : QIcon**

        This property holds the system tray icon

        On Windows, the system tray icon size is 16x16; on X11, the preferred
        size is 22x22. The icon will be scaled to the appropriate size as
        necessary.

        **Access functions:**

        QIcon **icon** () const
        void **setIcon** (const QIcon & **icon** )
        """
        ...

    def geometry(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#geometry

        **QRect QSystemTrayIcon::geometry() const**

        Returns the geometry of the system tray icon in screen coordinates.

        **See also** **visible** .
        """
        ...

    def contextMenu(self) -> QMenu:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#contextMenu

        **QMenu *QSystemTrayIcon::contextMenu() const**

        Returns the current context menu for the system tray entry.

        **See also** **setContextMenu** ().
        """
        ...

    def setContextMenu(self, menu: QMenu) -> None:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#setContextMenu

        **void QSystemTrayIcon::setContextMenu(QMenu * menu )**

        Sets the specified **menu** to be the context menu for the system tray
        icon.

        The menu will pop up when the user requests the context menu for the
        system tray icon by clicking the mouse button.

        On macOS, this is currently converted to a NSMenu, so the aboutToHide()
        signal is not emitted.

        **Note:** The system tray icon does not take ownership of the menu. You
        must ensure that it is deleted at the appropriate time by, for example,
        creating the menu with a suitable parent object.

        **See also** **contextMenu** ().
        """
        ...

    @property
    def activated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#activated

        **[signal] void
        QSystemTrayIcon::activated(QSystemTrayIcon::ActivationReason reason )**

        This signal is emitted when the user activates the system tray icon.
        **reason** specifies the reason for activation.
        **QSystemTrayIcon::ActivationReason**  enumerates the various reasons.

        **See also** **QSystemTrayIcon::ActivationReason** .
        """
        ...

    @property
    def messageClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsystemtrayicon.html#messageClicked

        **[signal] void QSystemTrayIcon::messageClicked()**

        This signal is emitted when the message displayed using **showMessage**
        () was clicked by the user.

        **Note:** We follow Microsoft Windows behavior, so the signal is also
        emitted when the user clicks on a tray icon with a balloon message
        displayed.

        **See also** **activated** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtGui import *
import enum


class QSurfaceFormat(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsurfaceformat.html

    **Detailed Description**

    The format includes the size of the color buffers, red, green, and blue; the
    size of the alpha buffer; the size of the depth and stencil buffers; and
    number of samples per pixel for multisampling. In addition, the format
    contains surface configuration parameters such as OpenGL profile and version
    for rendering, whether or not to enable stereo buffers, and swap behaviour.

    **Note:** When troubleshooting context or window format issues, it can be
    helpful to enable the logging category `qt.qpa.gl`. Depending on the
    platform, this may print useful debug information when it comes to OpenGL
    initialization and the native visual or framebuffer configurations which
    QSurfaceFormat gets mapped to.
    """

    class OpenGLContextProfile(enum.Enum):
        NoProfile: QSurfaceFormat = ...
        CoreProfile: QSurfaceFormat = ...
        CompatibilityProfile: QSurfaceFormat = ...

    class RenderableType(enum.Enum):
        DefaultRenderableType: QSurfaceFormat = ...
        OpenGL: QSurfaceFormat = ...
        OpenGLES: QSurfaceFormat = ...
        OpenVG: QSurfaceFormat = ...

    class SwapBehavior(enum.Enum):
        DefaultSwapBehavior: QSurfaceFormat = ...
        SingleBuffer: QSurfaceFormat = ...
        DoubleBuffer: QSurfaceFormat = ...
        TripleBuffer: QSurfaceFormat = ...

    class FormatOption(enum.Flag):
        StereoBuffers: QSurfaceFormat = ...
        DebugContext: QSurfaceFormat = ...
        DeprecatedFunctions: QSurfaceFormat = ...
        ResetNotification: QSurfaceFormat = ...
        ProtectedContent: QSurfaceFormat = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#QSurfaceFormat

        **QSurfaceFormat::QSurfaceFormat()**

        Constructs a default initialized QSurfaceFormat.

        **Note:** By default OpenGL 2.0 is requested since this provides the
        highest grade of portability between platforms and OpenGL
        implementations.
        """
        ...

    @typing.overload
    def __init__(self, options: "QSurfaceFormat.FormatOption") -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#QSurfaceFormat-1

        **QSurfaceFormat::QSurfaceFormat(QSurfaceFormat::FormatOptions options
        )**

        Constructs a QSurfaceFormat with the given format **options**.
        """
        ...

    @typing.overload
    def __init__(self, other: "QSurfaceFormat") -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#QSurfaceFormat-2

        **QSurfaceFormat::QSurfaceFormat(const QSurfaceFormat & other )**

        Constructs a copy of **other**.
        """
        ...

    def setColorSpace(self, colorSpace: QColorSpace) -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setColorSpace

        **[since 6.0] void QSurfaceFormat::setColorSpace(const QColorSpace &
        colorSpace )**

        Sets the preferred **colorSpace**.

        For example, this allows requesting windows with default framebuffers
        that are sRGB-capable on platforms that support it.

        **Note:** When the requested color space is not supported by the
        platform, the request is ignored. Query the **QSurfaceFormat**  after
        window creation to verify if the color space request could be honored or
        not.

        **Note:** This setting controls if the default framebuffer of the window
        is capable of updates and blending in a given color space. It does not
        change applications' output by itself. The applications' rendering code
        will still have to opt in via the appropriate OpenGL calls to enable
        updates and blending to be performed in the given color space instead of
        using the standard linear operations.

        This function was introduced in Qt 6.0.

        **See also** **colorSpace** ().
        """
        ...

    def colorSpace(self) -> QColorSpace:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#colorSpace

        **[since 5.10] const QColorSpace &QSurfaceFormat::colorSpace() const**

        Returns the color space.

        This function was introduced in Qt 5.10.

        **See also** **setColorSpace** ().
        """
        ...

    @staticmethod
    def defaultFormat() -> "QSurfaceFormat":
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#defaultFormat

        **[static, since 5.4] QSurfaceFormat QSurfaceFormat::defaultFormat()**

        Returns the global default surface format.

        When **setDefaultFormat** () is not called, this is a default-
        constructed **QSurfaceFormat** .

        This function was introduced in Qt 5.4.

        **See also** **setDefaultFormat** ().
        """
        ...

    @staticmethod
    def setDefaultFormat(format: "QSurfaceFormat") -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setDefaultFormat

        **[static, since 5.4] void QSurfaceFormat::setDefaultFormat(const
        QSurfaceFormat & format )**

        Sets the global default surface **format**.

        This format is used by default in **QOpenGLContext** , **QWindow** ,
        **QOpenGLWidget**  and similar classes.

        It can always be overridden on a per-instance basis by using the class
        in question's own setFormat() function. However, it is often more
        convenient to set the format for all windows once at the start of the
        application. It also guarantees proper behavior in cases where shared
        contexts are required, because settings the format via this function
        guarantees that all contexts and surfaces, even the ones created
        internally by Qt, will use the same format.

        **Note:** When setting **Qt::AA_ShareOpenGLContexts** , it is strongly
        recommended to place the call to this function before the construction
        of the **QGuiApplication**  or **QApplication** . Otherwise **format**
        will not be applied to the global share context and therefore issues may
        arise with context sharing afterwards.

        This function was introduced in Qt 5.4.

        **See also** **defaultFormat** ().
        """
        ...

    def setSwapInterval(self, interval: int) -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setSwapInterval

        **[since 5.3] void QSurfaceFormat::setSwapInterval(int interval )**

        Sets the preferred swap interval. The swap interval specifies the
        minimum number of video frames that are displayed before a buffer swap
        occurs. This can be used to sync the GL drawing into a window to the
        vertical refresh of the screen.

        Setting an **interval** value of 0 will turn the vertical refresh
        syncing off, any value higher than 0 will turn the vertical syncing on.
        Setting **interval** to a higher value, for example 10, results in
        having 10 vertical retraces between every buffer swap.

        The default interval is 1.

        Changing the swap interval may not be supported by the underlying
        platform. In this case, the request will be silently ignored.

        This function was introduced in Qt 5.3.

        **See also** **swapInterval** ().
        """
        ...

    def swapInterval(self) -> int:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#swapInterval

        **[since 5.3] int QSurfaceFormat::swapInterval() const**

        Returns the swap interval.

        This function was introduced in Qt 5.3.

        **See also** **setSwapInterval** ().
        """
        ...

    def options(self) -> "QSurfaceFormat.FormatOption":
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#options

        **[since 5.3] QSurfaceFormat::FormatOptions QSurfaceFormat::options()
        const**

        Returns the currently set format options.

        This function was introduced in Qt 5.3.

        **See also** **setOption** (), **setOptions** (), and **testOption** ().
        """
        ...

    def testOption(self, option: "QSurfaceFormat.FormatOption") -> bool:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#testOption

        **[since 5.3] bool
        QSurfaceFormat::testOption(QSurfaceFormat::FormatOption option ) const**

        Returns true if the format option **option** is set; otherwise returns
        false.

        This function was introduced in Qt 5.3.

        **See also** **options** ().
        """
        ...

    def setOption(self, option: "QSurfaceFormat.FormatOption", on: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setOption

        **[since 5.3] void
        QSurfaceFormat::setOption(QSurfaceFormat::FormatOption option , bool on
        = true)**

        Sets the format option **option** if **on** is true; otherwise, clears
        the option.

        To verify that an option was respected, compare the actual format to the
        requested format after surface/context creation.

        This function was introduced in Qt 5.3.

        **See also** **setOptions** (), **options** (), and **testOption** ().
        """
        ...

    def setOptions(self, options: "QSurfaceFormat.FormatOption") -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setOptions

        **[since 5.3] void
        QSurfaceFormat::setOptions(QSurfaceFormat::FormatOptions options )**

        Sets the format options to **options**.

        To verify that an option was respected, compare the actual format to the
        requested format after surface/context creation.

        This function was introduced in Qt 5.3.

        **See also** **options** () and **testOption** ().
        """
        ...

    def setVersion(self, major: int, minor: int) -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setVersion

        **void QSurfaceFormat::setVersion(int major , int minor )**

        Sets the desired **major** and **minor** OpenGL versions.

        The default version is 2.0.

        **See also** **version** ().
        """
        ...

    def version(self) -> typing.Tuple[int, int]:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#version

        **QPair<int, int> QSurfaceFormat::version() const**

        Returns a QPair<int, int> representing the OpenGL version.

        Useful for version checks, for example format.version() >= qMakePair(3,
        2)

        **See also** **setVersion** ().
        """
        ...

    def stereo(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#stereo

        **bool QSurfaceFormat::stereo() const**

        Returns `true` if stereo buffering is enabled; otherwise returns false.
        Stereo buffering is disabled by default.

        **See also** **setStereo** ().
        """
        ...

    def setStereo(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setStereo

        **void QSurfaceFormat::setStereo(bool enable )**

        If **enable** is true enables stereo buffering; otherwise disables
        stereo buffering.

        Stereo buffering is disabled by default.

        Stereo buffering provides extra color buffers to generate left-eye and
        right-eye images.

        **See also** **stereo** ().
        """
        ...

    def minorVersion(self) -> int:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#minorVersion

        **int QSurfaceFormat::minorVersion() const**

        Returns the minor OpenGL version.

        **See also** **setMinorVersion** ().
        """
        ...

    def setMinorVersion(self, minorVersion: int) -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setMinorVersion

        **void QSurfaceFormat::setMinorVersion(int minor )**

        Sets the desired **minor** OpenGL version.

        The default version is 2.0.

        **See also** **minorVersion** ().
        """
        ...

    def majorVersion(self) -> int:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#majorVersion

        **int QSurfaceFormat::majorVersion() const**

        Returns the major OpenGL version.

        The default version is 2.0.

        **See also** **setMajorVersion** ().
        """
        ...

    def setMajorVersion(self, majorVersion: int) -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setMajorVersion

        **void QSurfaceFormat::setMajorVersion(int major )**

        Sets the desired **major** OpenGL version.

        **See also** **majorVersion** ().
        """
        ...

    def renderableType(self) -> "QSurfaceFormat.RenderableType":
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#renderableType

        **QSurfaceFormat::RenderableType QSurfaceFormat::renderableType()
        const**

        Gets the renderable type.

        Chooses between desktop OpenGL, OpenGL ES, and **OpenVG** .

        **See also** **setRenderableType** ().
        """
        ...

    def setRenderableType(self, type: "QSurfaceFormat.RenderableType") -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setRenderableType

        **void QSurfaceFormat::setRenderableType(QSurfaceFormat::RenderableType
        type )**

        Sets the desired renderable **type**.

        Chooses between desktop OpenGL, OpenGL ES, and **OpenVG** .

        **See also** **renderableType** ().
        """
        ...

    def profile(self) -> "QSurfaceFormat.OpenGLContextProfile":
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#profile

        **QSurfaceFormat::OpenGLContextProfile QSurfaceFormat::profile() const**

        Get the configured OpenGL context profile.

        This setting is ignored if the requested OpenGL version is less than
        3.2.

        **See also** **setProfile** ().
        """
        ...

    def setProfile(self, profile: "QSurfaceFormat.OpenGLContextProfile") -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setProfile

        **void QSurfaceFormat::setProfile(QSurfaceFormat::OpenGLContextProfile
        profile )**

        Sets the desired OpenGL context **profile**.

        This setting is ignored if the requested OpenGL version is less than
        3.2.

        **See also** **profile** ().
        """
        ...

    def hasAlpha(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#hasAlpha

        **bool QSurfaceFormat::hasAlpha() const**

        Returns `true` if the alpha buffer size is greater than zero.

        This means that the surface might be used with per pixel translucency
        effects.
        """
        ...

    def swapBehavior(self) -> "QSurfaceFormat.SwapBehavior":
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#swapBehavior

        **QSurfaceFormat::SwapBehavior QSurfaceFormat::swapBehavior() const**

        Returns the configured swap behaviour.

        **See also** **setSwapBehavior** ().
        """
        ...

    def setSwapBehavior(self, behavior: "QSurfaceFormat.SwapBehavior") -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setSwapBehavior

        **void QSurfaceFormat::setSwapBehavior(QSurfaceFormat::SwapBehavior
        behavior )**

        Set the swap **behavior** of the surface.

        The swap behavior specifies whether single, double, or triple buffering
        is desired. The default, **DefaultSwapBehavior** , gives the default
        swap behavior of the platform.

        **See also** **swapBehavior** ().
        """
        ...

    def samples(self) -> int:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#samples

        **int QSurfaceFormat::samples() const**

        Returns the number of samples per pixel when multisampling is enabled,
        or `-1` when multisampling is disabled. The default return value is
        `-1`.

        **See also** **setSamples** ().
        """
        ...

    def setSamples(self, numSamples: int) -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setSamples

        **void QSurfaceFormat::setSamples(int numSamples )**

        Set the preferred number of samples per pixel when multisampling is
        enabled to **numSamples**. By default, multisampling is disabled.

        **See also** **samples** ().
        """
        ...

    def alphaBufferSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#alphaBufferSize

        **int QSurfaceFormat::alphaBufferSize() const**

        Get the size in bits of the alpha channel of the color buffer.

        **See also** **setAlphaBufferSize** ().
        """
        ...

    def setAlphaBufferSize(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setAlphaBufferSize

        **void QSurfaceFormat::setAlphaBufferSize(int size )**

        Set the desired **size** in bits of the alpha channel of the color
        buffer.

        **See also** **alphaBufferSize** ().
        """
        ...

    def blueBufferSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#blueBufferSize

        **int QSurfaceFormat::blueBufferSize() const**

        Get the size in bits of the blue channel of the color buffer.

        **See also** **setBlueBufferSize** ().
        """
        ...

    def setBlueBufferSize(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setBlueBufferSize

        **void QSurfaceFormat::setBlueBufferSize(int size )**

        Set the desired **size** in bits of the blue channel of the color
        buffer.

        **See also** **blueBufferSize** ().
        """
        ...

    def greenBufferSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#greenBufferSize

        **int QSurfaceFormat::greenBufferSize() const**

        Get the size in bits of the green channel of the color buffer.

        **See also** **setGreenBufferSize** ().
        """
        ...

    def setGreenBufferSize(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setGreenBufferSize

        **void QSurfaceFormat::setGreenBufferSize(int size )**

        Set the desired **size** in bits of the green channel of the color
        buffer.

        **See also** **greenBufferSize** ().
        """
        ...

    def redBufferSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#redBufferSize

        **int QSurfaceFormat::redBufferSize() const**

        Get the size in bits of the red channel of the color buffer.

        **See also** **setRedBufferSize** ().
        """
        ...

    def setRedBufferSize(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setRedBufferSize

        **void QSurfaceFormat::setRedBufferSize(int size )**

        Set the desired **size** in bits of the red channel of the color buffer.

        **See also** **redBufferSize** ().
        """
        ...

    def stencilBufferSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#stencilBufferSize

        **int QSurfaceFormat::stencilBufferSize() const**

        Returns the stencil buffer size in bits.

        **See also** **setStencilBufferSize** ().
        """
        ...

    def setStencilBufferSize(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setStencilBufferSize

        **void QSurfaceFormat::setStencilBufferSize(int size )**

        Set the preferred stencil buffer size to **size** bits.

        **See also** **stencilBufferSize** ().
        """
        ...

    def depthBufferSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#depthBufferSize

        **int QSurfaceFormat::depthBufferSize() const**

        Returns the depth buffer size.

        **See also** **setDepthBufferSize** ().
        """
        ...

    def setDepthBufferSize(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qsurfaceformat.html#setDepthBufferSize

        **void QSurfaceFormat::setDepthBufferSize(int size )**

        Set the minimum depth buffer size to **size**.

        **See also** **depthBufferSize** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtXml import *


class QDomDocument(QDomNode):
    """
    https://doc.qt.io/qt-6/qdomdocument.html

    **Detailed Description**

    The QDomDocument class represents the entire XML document. Conceptually, it
    is the root of the document tree, and provides the primary access to the
    document's data.

    Since elements, text nodes, comments, processing instructions, etc., cannot
    exist outside the context of a document, the document class also contains
    the factory functions needed to create these objects. The node objects
    created have an **ownerDocument** () function which associates them with the
    document within whose context they were created. The DOM classes that will
    be used most often are **QDomNode** , QDomDocument, **QDomElement**  and
    **QDomText** .

    The parsed XML is represented internally by a tree of objects that can be
    accessed using the various QDom classes. All QDom classes only **reference**
    objects in the internal tree. The internal objects in the DOM tree will get
    deleted once the last QDom object referencing them or the QDomDocument
    itself is deleted.

    Creation of elements, text nodes, etc. is done using the various factory
    functions provided in this class. Using the default constructors of the QDom
    classes will only result in empty objects that cannot be manipulated or
    inserted into the Document.

    The QDomDocument class has several functions for creating document data, for
    example, **createElement** (), **createTextNode** (), **createComment** (),
    **createCDATASection** (), **createProcessingInstruction** (),
    **createAttribute** () and **createEntityReference** (). Some of these
    functions have versions that support namespaces, i.e. **createElementNS** ()
    and **createAttributeNS** (). The **createDocumentFragment** () function is
    used to hold parts of the document; this is useful for manipulating for
    complex documents.

    The entire content of the document is set with **setContent** (). This
    function parses the string it is passed as an XML document and creates the
    DOM tree that represents the document. The root element is available using
    **documentElement** (). The textual representation of the document can be
    obtained using **toString** ().

    **Note:** The DOM tree might end up reserving a lot of memory if the XML
    document is big. For such documents, the **QXmlStreamReader**  or the
    QXmlQuery classes might be better solutions.

    It is possible to insert a node from another document into the document
    using **importNode** ().

    You can obtain a list of all the elements that have a particular tag with
    **elementsByTagName** () or with **elementsByTagNameNS** ().

    The QDom classes are typically used as follows:

    **QDomDocument**  doc("mydocument");
        **QFile**  file("mydocument.xml");
    if (!file.open(**QIODevice** ::ReadOnly))
            return;
        if
    (!doc.setContent(&file)) {
            file.close();
            return;
        }
    file.close();

        // print out the element names of all elements that
    are direct children
        // of the outermost element.
        **QDomElement**
    docElem = doc.documentElement();

        **QDomNode**  n =
    docElem.firstChild();
        while(!n.isNull()) {
            **QDomElement**  e =
    n.toElement(); // try to convert the node to an element.
    if(!e.isNull()) {
                cout << **qPrintable** (e.tagName()) << '\\n';
    // the node really is an element.
            }
            n = n.nextSibling();
    }

        // Here we append a new element to the end of the document
    **QDomElement**  elem = doc.createElement("img");
    elem.setAttribute("src", "myimage.png");
        docElem.appendChild(elem);

    Once `doc` and `elem` go out of scope, the whole internal tree representing
    the XML document is deleted.

    To create a document using DOM use code like this:

    **QDomDocument**  doc;
        **QDomElement**  root =
    doc.createElement("MyML");
        doc.appendChild(root);
    **QDomElement**  tag = doc.createElement("Greeting");
    root.appendChild(tag);

        **QDomText**  t = doc.createTextNode("Hello
    World");
        tag.appendChild(t);

        **QString**  xml = doc.toString();

    For further information about the Document Object Model see the Document
    Object Model (DOM) **Level 1**  and **Level 2 Core**  Specifications.

    **See also** **DOM Bookmarks Example**  and **Simple DOM Model Example** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#QDomDocument

        **QDomDocument::QDomDocument()**

        Constructs an empty document.
        """
        ...

    @typing.overload
    def __init__(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#QDomDocument-1

        **QDomDocument::QDomDocument(const QString & name )**

        Creates a document and sets the name of the document type to **name**.
        """
        ...

    @typing.overload
    def __init__(self, doctype: QDomDocumentType) -> None:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#QDomDocument-2

        **QDomDocument::QDomDocument(const QDomDocumentType & doctype )**

        Creates a document with the document type **doctype**.

        **See also** **QDomImplementation::createDocumentType** ().
        """
        ...

    @typing.overload
    def __init__(self, x: "QDomDocument") -> None:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#QDomDocument-3

        **QDomDocument::QDomDocument(const QDomDocument & x )**

        Constructs a copy of **x**.

        The data of the copy is shared (shallow copy): modifying one node will
        also change the other. If you want to make a deep copy, use
        **cloneNode** ().
        """
        ...

    def toByteArray(self, indent: int = ...) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#toByteArray

        **QByteArray QDomDocument::toByteArray(int indent = 1) const**

        Converts the parsed document back to its textual representation and
        returns a **QByteArray**  containing the data encoded as UTF-8.

        This function uses **indent** as the amount of space to indent
        subelements.

        **See also** **toString** ().
        """
        ...

    def toString(self, indent: int = ...) -> str:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#toString

        **QString QDomDocument::toString(int indent = 1) const**

        Converts the parsed document back to its textual representation.

        This function uses **indent** as the amount of space to indent
        subelements.

        If **indent** is -1, no whitespace at all is added.
        """
        ...

    @typing.overload
    def setContent(
        self, text: QtCore.QByteArray, namespaceProcessing: bool
    ) -> typing.Tuple[bool, str, int, int]:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#setContent

        **bool QDomDocument::setContent(const QByteArray & data , bool
        namespaceProcessing , QString * errorMsg = nullptr, int * errorLine =
        nullptr, int * errorColumn = nullptr)**

        This function parses the XML document from the byte array **data** and
        sets it as the content of the document. It tries to detect the encoding
        of the document as required by the XML specification.

        If **namespaceProcessing** is true, the parser recognizes namespaces in
        the XML file and sets the prefix name, local name and namespace URI to
        appropriate values. If **namespaceProcessing** is false, the parser does
        no namespace processing when it reads the XML file.

        If a parse error occurs, this function returns `false` and the error
        message is placed in `*` **errorMsg** , the line number in `*`
        **errorLine** and the column number in `*` **errorColumn** (unless the
        associated pointer is set to 0); otherwise this function returns `true`.
        The various error messages are described in the **QXmlParseException**
        class documentation. Note that, if you want to display these error
        messages to your application's users, they will be displayed in English
        unless they are explicitly translated.

        If **namespaceProcessing** is true, the function **QDomNode::prefix** ()
        returns a string for all elements and attributes. It returns an empty
        string if the element or attribute has no prefix.

        Text nodes consisting only of whitespace are stripped and won't appear
        in the **QDomDocument** . If this behavior is not desired, one can use
        the setContent() overload that allows a **QXmlReader**  to be supplied.

        If **namespaceProcessing** is false, the functions **QDomNode::prefix**
        (), **QDomNode::localName** () and **QDomNode::namespaceURI** () return
        an empty string.

        Entity references are handled as follows:

        * References to internal general entities and character entities
        occurring in the content are included. The result is a **QDomText**
        node with the references replaced by their corresponding entity values.
        * References to parameter entities occurring in the internal subset are
        included. The result is a **QDomDocumentType**  node which contains
        entity and notation declarations with the references replaced by their
        corresponding entity values.
          * Any general parsed entity reference
        which is not defined in the internal subset and which occurs in the
        content is represented as a **QDomEntityReference**  node.
          * Any
        parsed entity reference which is not defined in the internal subset and
        which occurs outside of the content is replaced with an empty string.
        * Any unparsed entity reference is replaced with an empty string.

        **See also** **QDomNode::namespaceURI** (), **QDomNode::localName** (),
        **QDomNode::prefix** (), **QString::isNull** (), and
        **QString::isEmpty** ().
        """
        ...

    @typing.overload
    def setContent(
        self, text: str, namespaceProcessing: bool
    ) -> typing.Tuple[bool, str, int, int]:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#setContent-1

        **bool QDomDocument::setContent(const QString & text , bool
        namespaceProcessing , QString * errorMsg = nullptr, int * errorLine =
        nullptr, int * errorColumn = nullptr)**

        This is an overloaded function.

        This function reads the XML document from the string **text** ,
        returning true if the content was successfully parsed; otherwise returns
        `false`. Since **text** is already a Unicode string, no encoding
        detection is done.
        """
        ...

    @typing.overload
    def setContent(
        self, dev: QtCore.QIODevice, namespaceProcessing: bool
    ) -> typing.Tuple[bool, str, int, int]:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#setContent-2

        **bool QDomDocument::setContent(QIODevice * dev , bool
        namespaceProcessing , QString * errorMsg = nullptr, int * errorLine =
        nullptr, int * errorColumn = nullptr)**

        This is an overloaded function.

        This function reads the XML document from the IO device **dev** ,
        returning true if the content was successfully parsed; otherwise returns
        `false`.

        **Note:** This method will try to open **dev** in read-only mode if it
        is not already open. In that case, the caller is responsible for calling
        close. This will change in Qt 7, which will no longer open **dev**.
        Applications shoul therefore open the device themselves before calling
        setContent.
        """
        ...

    @typing.overload
    def setContent(self, text: QtCore.QByteArray) -> typing.Tuple[bool, str, int, int]:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#setContent-3

        **bool QDomDocument::setContent(const QByteArray & buffer , QString *
        errorMsg = nullptr, int * errorLine = nullptr, int * errorColumn =
        nullptr)**

        This is an overloaded function.

        This function reads the XML document from the byte array **buffer** ,
        returning true if the content was successfully parsed; otherwise returns
        false.

        No namespace processing is performed.
        """
        ...

    @typing.overload
    def setContent(self, text: str) -> typing.Tuple[bool, str, int, int]:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#setContent-4

        **bool QDomDocument::setContent(const QString & text , QString *
        errorMsg = nullptr, int * errorLine = nullptr, int * errorColumn =
        nullptr)**

        This is an overloaded function.

        This function reads the XML document from the string **text** ,
        returning true if the content was successfully parsed; otherwise returns
        `false`. Since **text** is already a Unicode string, no encoding
        detection is performed.

        No namespace processing is performed either.
        """
        ...

    @typing.overload
    def setContent(self, dev: QtCore.QIODevice) -> typing.Tuple[bool, str, int, int]:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#setContent-6

        **[since 5.15] bool QDomDocument::setContent(QXmlStreamReader * reader ,
        bool namespaceProcessing , QString * errorMsg = nullptr, int * errorLine
        = nullptr, int * errorColumn = nullptr)**

        This is an overloaded function.

        This function reads the XML document from the **QXmlStreamReader**
        **reader** and parses it. Returns `true` if the content was successfully
        parsed; otherwise returns `false`.

        If **namespaceProcessing** is `true`, the parser recognizes namespaces
        in the XML file and sets the prefix name, local name and namespace URI
        to appropriate values. If **namespaceProcessing** is `false`, the parser
        does no namespace processing when it reads the XML file.

        If a parse error occurs, the error message is placed in `*` **errorMsg**
        , the line number in `*` **errorLine** and the column number in `*`
        **errorColumn** (unless the associated pointer is set to 0).

        This function was introduced in Qt 5.15.

        **See also** **QXmlStreamReader** .
        """
        ...

    @typing.overload
    def setContent(
        self, reader: QtCore.QXmlStreamReader, namespaceProcessing: bool
    ) -> typing.Tuple[bool, str, int, int]:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#setContent

        **bool QDomDocument::setContent(const QByteArray & data , bool
        namespaceProcessing , QString * errorMsg = nullptr, int * errorLine =
        nullptr, int * errorColumn = nullptr)**

        This function parses the XML document from the byte array **data** and
        sets it as the content of the document. It tries to detect the encoding
        of the document as required by the XML specification.

        If **namespaceProcessing** is true, the parser recognizes namespaces in
        the XML file and sets the prefix name, local name and namespace URI to
        appropriate values. If **namespaceProcessing** is false, the parser does
        no namespace processing when it reads the XML file.

        If a parse error occurs, this function returns `false` and the error
        message is placed in `*` **errorMsg** , the line number in `*`
        **errorLine** and the column number in `*` **errorColumn** (unless the
        associated pointer is set to 0); otherwise this function returns `true`.
        The various error messages are described in the **QXmlParseException**
        class documentation. Note that, if you want to display these error
        messages to your application's users, they will be displayed in English
        unless they are explicitly translated.

        If **namespaceProcessing** is true, the function **QDomNode::prefix** ()
        returns a string for all elements and attributes. It returns an empty
        string if the element or attribute has no prefix.

        Text nodes consisting only of whitespace are stripped and won't appear
        in the **QDomDocument** . If this behavior is not desired, one can use
        the setContent() overload that allows a **QXmlReader**  to be supplied.

        If **namespaceProcessing** is false, the functions **QDomNode::prefix**
        (), **QDomNode::localName** () and **QDomNode::namespaceURI** () return
        an empty string.

        Entity references are handled as follows:

        * References to internal general entities and character entities
        occurring in the content are included. The result is a **QDomText**
        node with the references replaced by their corresponding entity values.
        * References to parameter entities occurring in the internal subset are
        included. The result is a **QDomDocumentType**  node which contains
        entity and notation declarations with the references replaced by their
        corresponding entity values.
          * Any general parsed entity reference
        which is not defined in the internal subset and which occurs in the
        content is represented as a **QDomEntityReference**  node.
          * Any
        parsed entity reference which is not defined in the internal subset and
        which occurs outside of the content is replaced with an empty string.
        * Any unparsed entity reference is replaced with an empty string.

        **See also** **QDomNode::namespaceURI** (), **QDomNode::localName** (),
        **QDomNode::prefix** (), **QString::isNull** (), and
        **QString::isEmpty** ().
        """
        ...

    def nodeType(self) -> QDomNode.NodeType:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#nodeType

        **QDomNode::NodeType QDomDocument::nodeType() const**

        Returns `DocumentNode`.
        """
        ...

    def documentElement(self) -> "QDomElement":
        """
        https://doc.qt.io/qt-6/qdomdocument.html#documentElement

        **QDomElement QDomDocument::documentElement() const**

        Returns the root element of the document.
        """
        ...

    def implementation(self) -> QDomImplementation:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#implementation

        **QDomImplementation QDomDocument::implementation() const**

        Returns a **QDomImplementation**  object.
        """
        ...

    def doctype(self) -> QDomDocumentType:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#doctype

        **QDomDocumentType QDomDocument::doctype() const**

        Returns the document type of this document.
        """
        ...

    def elementById(self, elementId: str) -> "QDomElement":
        """
        https://doc.qt.io/qt-6/qdomdocument.html#elementById

        **QDomElement QDomDocument::elementById(const QString & elementId )**

        Returns the element whose ID is equal to **elementId**. If no element
        with the ID was found, this function returns a **null element** .

        Since the QDomClasses do not know which attributes are element IDs, this
        function returns always a **null element** . This may change in a future
        version.
        """
        ...

    def elementsByTagNameNS(self, nsURI: str, localName: str) -> QDomNodeList:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#elementsByTagNameNS

        **QDomNodeList QDomDocument::elementsByTagNameNS(const QString & nsURI ,
        const QString & localName )**

        Returns a **QDomNodeList**  that contains all the elements in the
        document with the local name **localName** and a namespace URI of
        **nsURI**. The order of the node list is the order they are encountered
        in a preorder traversal of the element tree.

        **See also** **elementsByTagName** () and
        **QDomElement::elementsByTagNameNS** ().
        """
        ...

    def createAttributeNS(self, nsURI: str, qName: str) -> "QDomAttr":
        """
        https://doc.qt.io/qt-6/qdomdocument.html#createAttributeNS

        **QDomAttr QDomDocument::createAttributeNS(const QString & nsURI , const
        QString & qName )**

        Creates a new attribute with namespace support that can be inserted into
        an element. The name of the attribute is **qName** and the namespace URI
        is **nsURI**. This function also sets **QDomNode::prefix** () and
        **QDomNode::localName** () to appropriate values (depending on **qName**
        ).

        If **qName** is not a valid XML name, the behavior of this function is
        governed by **QDomImplementation::InvalidDataPolicy** .

        **See also** **createAttribute** ().
        """
        ...

    def createElementNS(self, nsURI: str, qName: str) -> "QDomElement":
        """
        https://doc.qt.io/qt-6/qdomdocument.html#createElementNS

        **QDomElement QDomDocument::createElementNS(const QString & nsURI ,
        const QString & qName )**

        Creates a new element with namespace support that can be inserted into
        the DOM tree. The name of the element is **qName** and the namespace URI
        is **nsURI**. This function also sets **QDomNode::prefix** () and
        **QDomNode::localName** () to appropriate values (depending on **qName**
        ).

        If **qName** is an empty string, returns a null element regardless of
        whether the invalid data policy is set.

        **See also** **createElement** ().
        """
        ...

    def importNode(self, importedNode: QDomNode, deep: bool) -> QDomNode:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#importNode

        **QDomNode QDomDocument::importNode(const QDomNode & importedNode , bool
        deep )**

        Imports the node **importedNode** from another document to this
        document. **importedNode** remains in the original document; this
        function creates a copy that can be used within this document.

        This function returns the imported node that belongs to this document.
        The returned node has no parent. It is not possible to import
        **QDomDocument**  and **QDomDocumentType**  nodes. In those cases this
        function returns a **null node** .

        If **importedNode** is a **null node** , a null node is returned.

        If **deep** is true, this function imports not only the node
        **importedNode** but its whole subtree; if it is false, only the
        **importedNode** is imported. The argument **deep** has no effect on
        **QDomAttr**  and **QDomEntityReference**  nodes, since the descendants
        of **QDomAttr**  nodes are always imported and those of
        **QDomEntityReference**  nodes are never imported.

        The behavior of this function is slightly different depending on the
        node types:

        Node TypeBehavior
        **QDomAttr** The owner element is set to 0 and the
        specified flag is set to true in the generated attribute. The whole
        subtree of **importedNode** is always imported for attribute nodes:
        **deep** has no effect.
        **QDomDocument** Document nodes cannot be
        imported.
        **QDomDocumentFragment** If **deep** is true, this function
        imports the whole document fragment; otherwise it only generates an
        empty document fragment.
        **QDomDocumentType** Document type nodes
        cannot be imported.
        **QDomElement** Attributes for which
        **QDomAttr::specified** () is true are also imported, other attributes
        are not imported. If **deep** is true, this function also imports the
        subtree of **importedNode** ; otherwise it imports only the element node
        (and some attributes, see above).
        **QDomEntity** Entity nodes can be
        imported, but at the moment there is no way to use them since the
        document type is read-only in DOM level 2.
        **QDomEntityReference**
        Descendants of entity reference nodes are never imported: **deep** has
        no effect.
        **QDomNotation** Notation nodes can be imported, but at the
        moment there is no way to use them since the document type is read-only
        in DOM level 2.
        **QDomProcessingInstruction** The target and value of
        the processing instruction is copied to the new node.
        **QDomText** The
        text is copied to the new node.
        **QDomCDATASection** The text is
        copied to the new node.
        **QDomComment** The text is copied to the new
        node.

        **See also** **QDomElement::setAttribute** (),
        **QDomNode::insertBefore** (), **QDomNode::insertAfter** (),
        **QDomNode::replaceChild** (), **QDomNode::removeChild** (), and
        **QDomNode::appendChild** ().
        """
        ...

    def elementsByTagName(self, tagname: str) -> QDomNodeList:
        """
        https://doc.qt.io/qt-6/qdomdocument.html#elementsByTagName

        **QDomNodeList QDomDocument::elementsByTagName(const QString & tagname )
        const**

        Returns a **QDomNodeList** , that contains all the elements in the
        document with the name **tagname**. The order of the node list is the
        order they are encountered in a preorder traversal of the element tree.

        **See also** **elementsByTagNameNS** () and
        **QDomElement::elementsByTagName** ().
        """
        ...

    def createEntityReference(self, name: str) -> "QDomEntityReference":
        """
        https://doc.qt.io/qt-6/qdomdocument.html#createEntityReference

        **QDomEntityReference QDomDocument::createEntityReference(const QString
        & name )**

        Creates a new entity reference called **name** that can be inserted into
        the document, e.g. using **QDomNode::appendChild** ().

        If **name** is not a valid XML name, the behavior of this function is
        governed by **QDomImplementation::InvalidDataPolicy** .

        **See also** **QDomNode::appendChild** (), **QDomNode::insertBefore**
        (), and **QDomNode::insertAfter** ().
        """
        ...

    def createAttribute(self, name: str) -> "QDomAttr":
        """
        https://doc.qt.io/qt-6/qdomdocument.html#createAttribute

        **QDomAttr QDomDocument::createAttribute(const QString & name )**

        Creates a new attribute called **name** that can be inserted into an
        element, e.g. using **QDomElement::setAttributeNode** ().

        If **name** is not a valid XML name, the behavior of this function is
        governed by **QDomImplementation::InvalidDataPolicy** .

        **See also** **createAttributeNS** ().
        """
        ...

    def createProcessingInstruction(
        self, target: str, data: str
    ) -> "QDomProcessingInstruction":
        """
        https://doc.qt.io/qt-6/qdomdocument.html#createProcessingInstruction

        **QDomProcessingInstruction
        QDomDocument::createProcessingInstruction(const QString & target , const
        QString & data )**

        Creates a new processing instruction that can be inserted into the
        document, e.g. using **QDomNode::appendChild** (). This function sets
        the target for the processing instruction to **target** and the data to
        **data**.

        If **target** is not a valid XML name, or data if contains characters
        which cannot appear in a processing instruction, the behavior of this
        function is governed by **QDomImplementation::InvalidDataPolicy** .

        **See also** **QDomNode::appendChild** (), **QDomNode::insertBefore**
        (), and **QDomNode::insertAfter** ().
        """
        ...

    def createCDATASection(self, data: str) -> "QDomCDATASection":
        """
        https://doc.qt.io/qt-6/qdomdocument.html#createCDATASection

        **QDomCDATASection QDomDocument::createCDATASection(const QString &
        value )**

        Creates a new CDATA section for the string **value** that can be
        inserted into the document, e.g. using **QDomNode::appendChild** ().

        If **value** contains characters which cannot be stored in a CDATA
        section, the behavior of this function is governed by
        **QDomImplementation::InvalidDataPolicy** .

        **See also** **QDomNode::appendChild** (), **QDomNode::insertBefore**
        (), and **QDomNode::insertAfter** ().
        """
        ...

    def createComment(self, data: str) -> "QDomComment":
        """
        https://doc.qt.io/qt-6/qdomdocument.html#createComment

        **QDomComment QDomDocument::createComment(const QString & value )**

        Creates a new comment for the string **value** that can be inserted into
        the document, e.g. using **QDomNode::appendChild** ().

        If **value** contains characters which cannot be stored in an XML
        comment, the behavior of this function is governed by
        **QDomImplementation::InvalidDataPolicy** .

        **See also** **QDomNode::appendChild** (), **QDomNode::insertBefore**
        (), and **QDomNode::insertAfter** ().
        """
        ...

    def createTextNode(self, data: str) -> "QDomText":
        """
        https://doc.qt.io/qt-6/qdomdocument.html#createTextNode

        **QDomText QDomDocument::createTextNode(const QString & value )**

        Creates a text node for the string **value** that can be inserted into
        the document tree, e.g. using **QDomNode::appendChild** ().

        If **value** contains characters which cannot be stored as character
        data of an XML document (even in the form of character references), the
        behavior of this function is governed by
        **QDomImplementation::InvalidDataPolicy** .

        **See also** **QDomNode::appendChild** (), **QDomNode::insertBefore**
        (), and **QDomNode::insertAfter** ().
        """
        ...

    def createDocumentFragment(self) -> "QDomDocumentFragment":
        """
        https://doc.qt.io/qt-6/qdomdocument.html#createDocumentFragment

        **QDomDocumentFragment QDomDocument::createDocumentFragment()**

        Creates a new document fragment, that can be used to hold parts of the
        document, e.g. when doing complex manipulations of the document tree.
        """
        ...

    def createElement(self, tagName: str) -> "QDomElement":
        """
        https://doc.qt.io/qt-6/qdomdocument.html#createElement

        **QDomElement QDomDocument::createElement(const QString & tagName )**

        Creates a new element called **tagName** that can be inserted into the
        DOM tree, e.g. using **QDomNode::appendChild** ().

        If **tagName** is not a valid XML name, the behavior of this function is
        governed by **QDomImplementation::InvalidDataPolicy** .

        **See also** **createElementNS** (), **QDomNode::appendChild** (),
        **QDomNode::insertBefore** (), and **QDomNode::insertAfter** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtRemoteObjects import *
import enum


class QRemoteObjectHostBase(QRemoteObjectNode):
    """
    https://doc.qt.io/qt-6/qremoteobjecthostbase.html

    **Detailed Description**

    QRemoteObjectHostBase is a base class that cannot be instantiated directly.
    It provides the **enableRemoting**  and **disableRemoting**  functionality
    shared by all host nodes (**Host**  and **RegistryHost** ) as well as the
    logic required to expose **Source**  objects on the Remote Objects network.
    """

    class AllowedSchemas(enum.Enum):
        BuiltInSchemasOnly: QRemoteObjectHostBase = ...
        AllowExternalRegistration: QRemoteObjectHostBase = ...

    def reverseProxy(self) -> bool:
        """
        https://doc.qt.io/qt-6/qremoteobjecthostbase.html#reverseProxy

        **[since 5.11] bool QRemoteObjectHostBase::reverseProxy(QRemoteObjectHos
        tBase::RemoteObjectNameFilter filter = [](QStringView, QStringView)
        {return true; })**

        Forwards remote objects to another network.

        The reverseProxy() function allows the **proxy** () functionality to be
        extended, in effect mirroring the proxy functionality in the "reverse"
        direction. These are distinct, because node communication is not
        symmetric, one side calls **enableRemoting** () with a **Source**
        object, the other side calls **acquire** () to get a **Replica** . Using
        **proxy** () allows you to "observe" objects on a target device remotely
        via acquire, but it does not allow off-target **Source**  objects to be
        acquired from the device's local:* network. That is where reverseProxy()
        comes in. If a proxyNode is created like so:

        // myInternalHost is a node only visible on the device...
        **QRemoteObjectHost**  myInternalHost("local:MyHost");

            //
        RegistryHost node, listening on port 12123, so visible to other
            //
        devices.  The node must be a RegistryHost, so the Sources on
            // the
        "outside" network can be forwarded to the inner network.
        **QRemoteObjectRegistryHost**  proxyNode("tcp://localhost:12123");
        // Enable proxying objects from nodes on the local machine's internal
        // QtRO bus.  Note the hostUrl parameter is now needed.
        proxyNode.proxy("local:registry", "local:fromProxy");
        proxyNode.reverseProxy();

        And from another device you create another node:

        // NB: localhost resolves to a different ip address than proxyNode
        **QRemoteObjectHost**  nodeOnRemoteDevice("tcp://localhost:23234");
        // Connect to the target's proxyNode directly, or use a tcp registry...
        nodeOnRemoteDevice.connectToNode("tcp://<target device>:12123");
        // Because of the reverseProxy, we can expose objects on this device
        // and they will make their way to proxyNode...
        nodeOnRemoteDevice.enableRemoting<OtherObject>(&otherObject);

        // Acquire() can now see the objects on other devices through proxyNode,
        // due to the reverseProxy call.
            OtherObject *oo =
        myInternalHost.acquire<OtherObject>();

        While the **proxy** () functionality allows **Source**  objects on
        another network to be acquired(), reverseProxy() allows **Source**
        objects to be "pushed" to an otherwise inaccessible network.

        **Note:****proxy** () needs to be called before reverseProxy(), and a
        hostUrl needs to be provided to **proxy**  for reverseProxy() to work.
        The reverseProxy() method allows a separate **filter** to be applied.
        This reverseProxy specific filter will receive notifications of new
        **Source**  objects on `proxyNode` and acquire them on the internal node
        if they pass the **filter**.

        Returns `true` on success, `false` otherwise.

        **Note:** Currently the reverse proxy functionality is supported only
        for **QRemoteObjectRegistryHost** . Calling this method on a
        **QRemoteObjectHost**  node will always return `false`.

        This function was introduced in Qt 5.11.

        **See also** **proxy** ().
        """
        ...

    def proxy(self, registryUrl: QtCore.QUrl, hostUrl: QtCore.QUrl = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qremoteobjecthostbase.html#proxy

        **[since 5.11] bool QRemoteObjectHostBase::proxy(const QUrl &
        registryUrl , const QUrl & hostUrl = {},
        QRemoteObjectHostBase::RemoteObjectNameFilter filter = [](QStringView,
        QStringView) {return true; })**

        Forward Remote Objects from another network

        The proxy functionality is useful when you want to share **Source**
        objects over multiple networks. For instance, if you have an embedded
        target using target-only connections (like local) and you want to make
        some of those same objects available externally.

        As a concrete example, say you have a set of processes talking to each
        other on your target hardware using a registry, with the **Registry**
        at "local:registry" and separate processes using a node at
        "local:MyHost" that holds **Source**  objects. If you wanted to access
        these objects, but over tcp, you could create a new proxyNode like so:

        // myInternalHost is a node only visible on the device...
        **QRemoteObjectHost**  myInternalHost("local:MyHost");
        myInternalHost.enableRemoting<SomeObject>(&someObject);

            //
        Regular host node, listening on port 12123, so visible to other
            //
        devices
            **QRemoteObjectHost**  proxyNode("tcp://localhost:12123");
        // Enable proxying objects from nodes on the local machine's internal
        // QtRO bus
            proxyNode.proxy("local:registry");

        And from another device you create another node:

        // NB: localhost resolves to a different ip address than proxyNode
        **QRemoteObjectHost**  nodeOnRemoteDevice("tcp://localhost:23234");
        // Connect to the target's proxyNode directly, or use a tcp registry...
        nodeOnRemoteDevice.connectToNode("tcp://<target device>:12123");
        // Because of the proxy, we can get the object over tcp/ip port 12123,
        // even though we can't connect directly to "local:MyHost"
        SomeObject *so = nodeOnRemoteDevice.acquire<SomeObject>();

        This would (internally) create a node in proxyNode, which (again
        internally/automatically) connects to the provided registry (given by
        the **registryUrl** parameter, "local:registry" in this example).
        Whenever local:registry emits the **remoteObjectAdded**  signal, the
        `QRemoteObjectSourceLocation` is passed to the **filter** given to the
        proxy call. If this method returns true (the default filter simply
        returns true without any filtering), the object is acquired() from the
        internal node and **enableRemoting** () (once the replica is
        initialized) is called on proxyNode.

        If a **hostUrl** is provided (which is required to enable
        **reverseProxy** , but not needed otherwise), the internal node will be
        a **QRemoteObjectHost**  node configured with the provided address. If
        no **hostUrl** is provided, the internal node will be a
        **QRemoteObjectNode**  (not HostNode).

        Returns `true` if the object is acquired from the internal node.

        This function was introduced in Qt 5.11.

        **See also** **reverseProxy** ().
        """
        ...

    def addHostSideConnection(self, ioDevice: QtCore.QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qremoteobjecthostbase.html#addHostSideConnection

        **[since 5.12] void
        QRemoteObjectHostBase::addHostSideConnection(QIODevice * ioDevice )**

        In order to **QRemoteObjectHost::enableRemoting** () **Source**  objects
        over **External QIODevices** , Qt Remote Objects needs access to the
        communications channel (a **QIODevice** ) between the respective nodes.
        It is the addHostSideConnection() call that enables this on the
        **Source**  side, taking the **ioDevice** as input. Any
        **enableRemoting** () call will still work without calling
        addHostSideConnection, but the Node will not be able to share the
        **Source**  objects without being provided the connection to the Replica
        node. Before calling this function you must call **setHostUrl** () with
        a unique URL and **AllowExternalRegistration** .

        This function was introduced in Qt 5.12.

        **See also** **addClientSideConnection** .
        """
        ...

    def disableRemoting(self, remoteObject: QtCore.QObject) -> bool:
        """
        https://doc.qt.io/qt-6/qremoteobjecthostbase.html#disableRemoting

        **[invokable] bool QRemoteObjectHostBase::disableRemoting(QObject *
        remoteObject )**

        Disables remote access for the **QObject**  **remoteObject**. Returns
        `false` if the current node is a client node or if the **remoteObject**
        is not registered, and returns `true` if remoting is successfully
        disabled for the Source object.

        **Warning:** Replicas of this object will no longer be valid after
        calling this method.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **enableRemoting** ().
        """
        ...

    @typing.overload
    def enableRemoting(self, object: QtCore.QObject, name: str = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qremoteobjecthostbase.html#enableRemoting

        **template <template <typename> class ApiDefinition, typename
        ObjectType> bool QRemoteObjectHostBase::enableRemoting(ObjectType *
        object )**

        This templated function overload enables a host node to provide remote
        access to a **QObject**  **object** with a specified (and compile-time
        checked) interface. Client nodes connected to the node hosting this
        object may obtain Replicas of this Source.

        This is best illustrated by example:

        #include "rep_TimeModel_source.h"
            MinuteTimer timer;
        hostNode.enableRemoting<MinuteTimerSourceAPI>(&timer);

        Here the MinuteTimerSourceAPI is the set of Signals/Slots/Properties
        defined by the TimeModel.rep file. Compile time checks are made to
        verify the input **QObject**  can expose the requested API, it will fail
        to compile otherwise. This allows a subset of **object** 's interface to
        be exposed, and allows the types of conversions supported by Signal/Slot
        connections.

        Returns `false` if the current node is a client node, or if the
        **QObject**  is already registered to be remoted, and `true` if remoting
        is successfully enabled for the **QObject** .

        **See also** **disableRemoting** ().
        """
        ...

    @typing.overload
    def enableRemoting(
        self,
        model: QtCore.QAbstractItemModel,
        name: str,
        roles: typing.Iterable[int],
        selectionModel: typing.Optional[QtCore.QItemSelectionModel] = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qremoteobjecthostbase.html#enableRemoting-1

        **[invokable] bool QRemoteObjectHostBase::enableRemoting(QObject *
        object , const QString & name = QString())**

        Enables a host node to dynamically provide remote access to the
        **QObject**  **object**. Client nodes connected to the node hosting this
        object may obtain Replicas of this Source.

        The optional **name** defines the lookup-name under which the
        **QObject**  can be acquired using **QRemoteObjectNode::acquire** () .
        If not explicitly set then the name given in the
        QCLASSINFO_REMOTEOBJECT_TYPE will be used. If no such macro was defined
        for the **QObject**  then the **QObject::objectName** () is used.

        Returns `false` if the current node is a client node, or if the
        **QObject**  is already registered to be remoted, and `true` if remoting
        is successfully enabled for the dynamic **QObject** .

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **disableRemoting** ().
        """
        ...

    def setName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qremoteobjecthostbase.html#setName

        **[override virtual] void QRemoteObjectHostBase::setName(const QString &
        name )**

        Reimplements: **QRemoteObjectNode::setName** (const QString &name).

        Similar to **QObject::setObjectName** () (which this method calls), but
        this version also applies the **name** to internal classes as well,
        which are used in some of the debugging output.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QSyntaxHighlighter(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qsyntaxhighlighter.html

    **Detailed Description**

    The QSyntaxHighlighter class is a base class for implementing
    **QTextDocument**  syntax highlighters. A syntax highligher automatically
    highlights parts of the text in a **QTextDocument** . Syntax highlighters
    are often used when the user is entering text in a specific format (for
    example source code) and help the user to read the text and identify syntax
    errors.

    To provide your own syntax highlighting, you must subclass
    QSyntaxHighlighter and reimplement **highlightBlock** ().

    When you create an instance of your QSyntaxHighlighter subclass, pass it the
    **QTextDocument**  that you want the syntax highlighting to be applied to.
    For example:

    **QTextEdit**  *editor = new **QTextEdit** ;
        MyHighlighter *highlighter
    = new MyHighlighter(editor->document());

    After this your **highlightBlock** () function will be called automatically
    whenever necessary. Use your **highlightBlock** () function to apply
    formatting (e.g. setting the font and color) to the text that is passed to
    it. QSyntaxHighlighter provides the **setFormat** () function which applies
    a given **QTextCharFormat**  on the current text block. For example:

    void MyHighlighter::highlightBlock(const **QString**  &text)
        {
    **QTextCharFormat**  myClassFormat;
    myClassFormat.setFontWeight(**QFont** ::Bold);
    myClassFormat.setForeground(Qt::darkMagenta);
    **QRegularExpression**  expression("\\\\bMy[A-Za-z]+\\\\b");
    **QRegularExpressionMatchIterator**  i = expression.globalMatch(text);
    while (i.hasNext()) {
                **QRegularExpressionMatch**  match =
    i.next();
                setFormat(match.capturedStart(),
    match.capturedLength(), myClassFormat);
            }
        }

    Some syntaxes can have constructs that span several text blocks. For
    example, a C++ syntax highlighter should be able to cope with `/``*...*``/`
    multiline comments. To deal with these cases it is necessary to know the end
    state of the previous text block (e.g. "in comment").

    Inside your **highlightBlock** () implementation you can query the end state
    of the previous text block using the **previousBlockState** () function.
    After parsing the block you can save the last state using
    **setCurrentBlockState** ().

    The **currentBlockState** () and **previousBlockState** () functions return
    an int value. If no state is set, the returned value is -1. You can
    designate any other value to identify any given state using the
    **setCurrentBlockState** () function. Once the state is set the
    **QTextBlock**  keeps that value until it is set set again or until the
    corresponding paragraph of text is deleted.

    For example, if you're writing a simple C++ syntax highlighter, you might
    designate 1 to signify "in comment":

    **QTextCharFormat**  multiLineCommentFormat;
    multiLineCommentFormat.setForeground(Qt::red);
    **QRegularExpression**  startExpression("/\\\\*");
        **QRegularExpression**
    endExpression("\\\\*/");

        setCurrentBlockState(0);

        int
    startIndex = 0;
        if (previousBlockState() != 1)
            startIndex =
    text.indexOf(startExpression);

        while (startIndex >= 0) {
    **QRegularExpressionMatch**  endMatch;
            int endIndex =
    text.indexOf(endExpression, startIndex, &endMatch);
            int
    commentLength;
            if (endIndex == -1) {
    setCurrentBlockState(1);
                commentLength = text.length() -
    startIndex;
            } else {
                commentLength = endIndex -
    startIndex
                                + endMatch.capturedLength();
    }
            setFormat(startIndex, commentLength, multiLineCommentFormat);
    startIndex = text.indexOf(startExpression,
    startIndex + commentLength);
        }

    In the example above, we first set the current block state to 0. Then, if
    the previous block ended within a comment, we highlight from the beginning
    of the current block (`startIndex = 0`). Otherwise, we search for the given
    start expression. If the specified end expression cannot be found in the
    text block, we change the current block state by calling
    **setCurrentBlockState** (), and make sure that the rest of the block is
    highlighted.

    In addition you can query the current formatting and user data using the
    **format** () and **currentBlockUserData** () functions respectively. You
    can also attach user data to the current text block using the
    **setCurrentBlockUserData** () function. **QTextBlockUserData**  can be used
    to store custom settings. In the case of syntax highlighting, it is in
    particular interesting as cache storage for information that you may figure
    out while parsing the paragraph's text. For an example, see the
    **setCurrentBlockUserData** () documentation.

    **See also** **QTextDocument**  and **Syntax Highlighter Example** .
    """

    @typing.overload
    def __init__(self, parent: "QTextDocument") -> None:
        """
        https://doc.qt.io/qt-6/qsyntaxhighlighter.html#QSyntaxHighlighter

        **QSyntaxHighlighter::QSyntaxHighlighter(QObject * parent )**

        Constructs a QSyntaxHighlighter with the given **parent**.

        If the parent is a **QTextEdit** , it installs the syntax highlighter on
        the parents document. The specified **QTextEdit**  also becomes the
        owner of the QSyntaxHighlighter.
        """
        ...

    @typing.overload
    def __init__(self, parent: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qsyntaxhighlighter.html#QSyntaxHighlighter-1

        **QSyntaxHighlighter::QSyntaxHighlighter(QTextDocument * parent )**

        Constructs a QSyntaxHighlighter and installs it on **parent**. The
        specified **QTextDocument**  also becomes the owner of the
        QSyntaxHighlighter.
        """
        ...

    def currentBlock(self) -> "QTextBlock":
        """
        https://doc.qt.io/qt-6/qsyntaxhighlighter.html#currentBlock

        **[protected] QTextBlock QSyntaxHighlighter::currentBlock() const**

        Returns the current text block.
        """
        ...

    def currentBlockUserData(self) -> "QTextBlockUserData":
        """
        https://doc.qt.io/qt-6/qsyntaxhighlighter.html#currentBlockUserData

        **[protected] QTextBlockUserData
        *QSyntaxHighlighter::currentBlockUserData() const**

        Returns the **QTextBlockUserData**  object previously attached to the
        current text block.

        **See also** **QTextBlock::userData** () and **setCurrentBlockUserData**
        ().
        """
        ...

    def setCurrentBlockUserData(self, data: "QTextBlockUserData") -> None:
        """
        https://doc.qt.io/qt-6/qsyntaxhighlighter.html#setCurrentBlockUserData

        **[protected] void
        QSyntaxHighlighter::setCurrentBlockUserData(QTextBlockUserData * data
        )**

        Attaches the given **data** to the current text block. The ownership is
        passed to the underlying text document, i.e. the provided
        **QTextBlockUserData**  object will be deleted if the corresponding text
        block gets deleted.

        **QTextBlockUserData**  can be used to store custom settings. In the
        case of syntax highlighting, it is in particular interesting as cache
        storage for information that you may figure out while parsing the
        paragraph's text.

        For example while parsing the text, you can keep track of parenthesis
        characters that you encounter ('{[(' and the like), and store their
        relative position and the actual **QChar**  in a simple class derived
        from **QTextBlockUserData** :

        struct ParenthesisInfo
            {
                **QChar**  character;
                int
        position;
            };

            struct BlockData : public
        **QTextBlockUserData**
            {
                **QList** <ParenthesisInfo>
        parentheses;
            };

        During cursor navigation in the associated editor, you can ask the
        current **QTextBlock**  (retrieved using the **QTextCursor::block** ()
        function) if it has a user data object set and cast it to your
        `BlockData` object. Then you can check if the current cursor position
        matches with a previously recorded parenthesis position, and, depending
        on the type of parenthesis (opening or closing), find the next opening
        or closing parenthesis on the same level.

        In this way you can do a visual parenthesis matching and highlight from
        the current cursor position to the matching parenthesis. That makes it
        easier to spot a missing parenthesis in your code and to find where a
        corresponding opening/closing parenthesis is when editing parenthesis
        intensive code.

        **See also** **currentBlockUserData** () and **QTextBlock::setUserData**
        ().
        """
        ...

    def setCurrentBlockState(self, newState: int) -> None:
        """
        https://doc.qt.io/qt-6/qsyntaxhighlighter.html#setCurrentBlockState

        **[protected] void QSyntaxHighlighter::setCurrentBlockState(int newState
        )**

        Sets the state of the current text block to **newState**.

        **See also** **currentBlockState** () and **highlightBlock** ().
        """
        ...

    def currentBlockState(self) -> int:
        """
        https://doc.qt.io/qt-6/qsyntaxhighlighter.html#currentBlockState

        **[protected] int QSyntaxHighlighter::currentBlockState() const**

        Returns the state of the current text block. If no value is set, the
        returned value is -1.

        **See also** **setCurrentBlockState** ().
        """
        ...

    def previousBlockState(self) -> int:
        """
        https://doc.qt.io/qt-6/qsyntaxhighlighter.html#previousBlockState

        **[protected] int QSyntaxHighlighter::previousBlockState() const**

        Returns the end state of the text block previous to the syntax
        highlighter's current block. If no value was previously set, the
        returned value is -1.

        **See also** **highlightBlock** () and **setCurrentBlockState** ().
        """
        ...

    def format(self, pos: int) -> "QTextCharFormat":
        """
        https://doc.qt.io/qt-6/qsyntaxhighlighter.html#format

        **[protected] QTextCharFormat QSyntaxHighlighter::format(int position )
        const**

        Returns the format at **position** inside the syntax highlighter's
        current text block.

        **See also** **setFormat** ().
        """
        ...

    @typing.overload
    def setFormat(self, start: int, count: int, format: "QTextCharFormat") -> None:
        """
        https://doc.qt.io/qt-6/qsyntaxhighlighter.html#setFormat

        **[protected] void QSyntaxHighlighter::setFormat(int start , int count ,
        const QTextCharFormat & format )**

        This function is applied to the syntax highlighter's current text block
        (i.e. the text that is passed to the **highlightBlock** () function).

        The specified **format** is applied to the text from the **start**
        position for a length of **count** characters (if **count** is 0,
        nothing is done). The formatting properties set in **format** are merged
        at display time with the formatting information stored directly in the
        document, for example as previously set with **QTextCursor** 's
        functions. Note that the document itself remains unmodified by the
        format set through this function.

        **See also** **format** () and **highlightBlock** ().
        """
        ...

    @typing.overload
    def setFormat(
        self,
        start: int,
        count: int,
        color: typing.Union[QColor, QtCore.Qt.GlobalColor, int, QGradient],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsyntaxhighlighter.html#setFormat-1

        **[protected] void QSyntaxHighlighter::setFormat(int start , int count ,
        const QColor & color )**

        This is an overloaded function.

        The specified **color** is applied to the current text block from the
        **start** position for a length of **count** characters.

        The other attributes of the current text block, e.g. the font and
        background color, are reset to default values.

        **See also** **format** () and **highlightBlock** ().
        """
        ...

    @typing.overload
    def setFormat(self, start: int, count: int, font: QFont) -> None:
        """
        https://doc.qt.io/qt-6/qsyntaxhighlighter.html#setFormat-2

        **[protected] void QSyntaxHighlighter::setFormat(int start , int count ,
        const QFont & font )**

        This is an overloaded function.

        The specified **font** is applied to the current text block from the
        **start** position for a length of **count** characters.

        The other attributes of the current text block, e.g. the font and
        background color, are reset to default values.

        **See also** **format** () and **highlightBlock** ().
        """
        ...

    def highlightBlock(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qsyntaxhighlighter.html#highlightBlock

        **[pure virtual protected] void QSyntaxHighlighter::highlightBlock(const
        QString & text )**

        Highlights the given text block. This function is called when necessary
        by the rich text engine, i.e. on text blocks which have changed.

        To provide your own syntax highlighting, you must subclass
        **QSyntaxHighlighter**  and reimplement highlightBlock(). In your
        reimplementation you should parse the block's **text** and call
        **setFormat** () as often as necessary to apply any font and color
        changes that you require. For example:

        void MyHighlighter::highlightBlock(const **QString**  &text)
            {
        **QTextCharFormat**  myClassFormat;
        myClassFormat.setFontWeight(**QFont** ::Bold);
        myClassFormat.setForeground(Qt::darkMagenta);
        **QRegularExpression**  expression("\\\\bMy[A-Za-z]+\\\\b");
        **QRegularExpressionMatchIterator**  i = expression.globalMatch(text);
        while (i.hasNext()) {
                    **QRegularExpressionMatch**  match =
        i.next();
                    setFormat(match.capturedStart(),
        match.capturedLength(), myClassFormat);
                }
            }

        See the **Detailed Description**  for examples of using
        **setCurrentBlockState** (), **currentBlockState** () and
        **previousBlockState** () to handle syntaxes with constructs that span
        several text blocks

        **See also** **previousBlockState** (), **setFormat** (), and
        **setCurrentBlockState** ().
        """
        ...

    def rehighlightBlock(self, block: "QTextBlock") -> None:
        """
        https://doc.qt.io/qt-6/qsyntaxhighlighter.html#rehighlightBlock

        **[slot] void QSyntaxHighlighter::rehighlightBlock(const QTextBlock &
        block )**

        Reapplies the highlighting to the given **QTextBlock**  **block**.

        **See also** **rehighlight** ().
        """
        ...

    def rehighlight(self) -> None:
        """
        https://doc.qt.io/qt-6/qsyntaxhighlighter.html#rehighlight

        **[slot] void QSyntaxHighlighter::rehighlight()**

        Reapplies the highlighting to the whole document.

        **See also** **rehighlightBlock** ().
        """
        ...

    def document(self) -> "QTextDocument":
        """
        https://doc.qt.io/qt-6/qsyntaxhighlighter.html#document

        **QTextDocument *QSyntaxHighlighter::document() const**

        Returns the **QTextDocument**  on which this syntax highlighter is
        installed.

        **See also** **setDocument** ().
        """
        ...

    def setDocument(self, doc: "QTextDocument") -> None:
        """
        https://doc.qt.io/qt-6/qsyntaxhighlighter.html#setDocument

        **void QSyntaxHighlighter::setDocument(QTextDocument * doc )**

        Installs the syntax highlighter on the given **QTextDocument**  **doc**.
        A **QSyntaxHighlighter**  can only be used with one document at a time.

        **See also** **document** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNetwork import *
import enum


class QNetworkRequest(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qnetworkrequest.html

    **Detailed Description**

    QNetworkRequest is part of the Network Access API and is the class holding
    the information necessary to send a request over the network. It contains a
    URL and some ancillary information that can be used to modify the request.

    **See also** **QNetworkReply**  and **QNetworkAccessManager** .
    """

    class TransferTimeoutConstant(enum.Enum):
        DefaultTransferTimeoutConstant: QNetworkRequest = ...

    class RedirectPolicy(enum.Enum):
        ManualRedirectPolicy: QNetworkRequest = ...
        NoLessSafeRedirectPolicy: QNetworkRequest = ...
        SameOriginRedirectPolicy: QNetworkRequest = ...
        UserVerifiedRedirectPolicy: QNetworkRequest = ...

    class Priority(enum.Enum):
        HighPriority: QNetworkRequest = ...
        NormalPriority: QNetworkRequest = ...
        LowPriority: QNetworkRequest = ...

    class LoadControl(enum.Enum):
        Automatic: QNetworkRequest = ...
        Manual: QNetworkRequest = ...

    class CacheLoadControl(enum.Enum):
        AlwaysNetwork: QNetworkRequest = ...
        PreferNetwork: QNetworkRequest = ...
        PreferCache: QNetworkRequest = ...
        AlwaysCache: QNetworkRequest = ...

    class Attribute(enum.Enum):
        HttpStatusCodeAttribute: QNetworkRequest = ...
        HttpReasonPhraseAttribute: QNetworkRequest = ...
        RedirectionTargetAttribute: QNetworkRequest = ...
        ConnectionEncryptedAttribute: QNetworkRequest = ...
        CacheLoadControlAttribute: QNetworkRequest = ...
        CacheSaveControlAttribute: QNetworkRequest = ...
        SourceIsFromCacheAttribute: QNetworkRequest = ...
        DoNotBufferUploadDataAttribute: QNetworkRequest = ...
        HttpPipeliningAllowedAttribute: QNetworkRequest = ...
        HttpPipeliningWasUsedAttribute: QNetworkRequest = ...
        CustomVerbAttribute: QNetworkRequest = ...
        CookieLoadControlAttribute: QNetworkRequest = ...
        AuthenticationReuseAttribute: QNetworkRequest = ...
        CookieSaveControlAttribute: QNetworkRequest = ...
        BackgroundRequestAttribute: QNetworkRequest = ...
        EmitAllUploadProgressSignalsAttribute: QNetworkRequest = ...
        Http2AllowedAttribute: QNetworkRequest = ...
        Http2WasUsedAttribute: QNetworkRequest = ...
        OriginalContentLengthAttribute: QNetworkRequest = ...
        RedirectPolicyAttribute: QNetworkRequest = ...
        Http2DirectAttribute: QNetworkRequest = ...
        AutoDeleteReplyOnFinishAttribute: QNetworkRequest = ...
        User: QNetworkRequest = ...
        UserMax: QNetworkRequest = ...

    class KnownHeaders(enum.Enum):
        ContentTypeHeader: QNetworkRequest = ...
        ContentLengthHeader: QNetworkRequest = ...
        LocationHeader: QNetworkRequest = ...
        LastModifiedHeader: QNetworkRequest = ...
        CookieHeader: QNetworkRequest = ...
        SetCookieHeader: QNetworkRequest = ...
        ContentDispositionHeader: QNetworkRequest = ...
        UserAgentHeader: QNetworkRequest = ...
        ServerHeader: QNetworkRequest = ...
        IfModifiedSinceHeader: QNetworkRequest = ...
        ETagHeader: QNetworkRequest = ...
        IfMatchHeader: QNetworkRequest = ...
        IfNoneMatchHeader: QNetworkRequest = ...

    @typing.overload
    def __init__(self, url: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#QNetworkRequest

        **QNetworkRequest::QNetworkRequest()**

        Constructs a QNetworkRequest object with no URL to be requested. Use
        **setUrl** () to set one.

        **See also** **url** () and **setUrl** ().
        """
        ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#QNetworkRequest-1

        **QNetworkRequest::QNetworkRequest(const QUrl & url )**

        Constructs a QNetworkRequest object with **url** as the URL to be
        requested.

        **See also** **url** () and **setUrl** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QNetworkRequest") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#QNetworkRequest-2

        **QNetworkRequest::QNetworkRequest(const QNetworkRequest & other )**

        Creates a copy of **other**.
        """
        ...

    def setDecompressedSafetyCheckThreshold(self, threshold: int) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#setDecompressedSafetyCheckTh
        reshold

        **[since 6.2] void
        QNetworkRequest::setDecompressedSafetyCheckThreshold(qint64 threshold
        )**

        Sets the **threshold** for archive bomb checks.

        Some supported compression algorithms can, in a tiny compressed file,
        encode a spectacularly huge decompressed file. This is only possible if
        the decompressed content is extremely monotonous, which is seldom the
        case for real files being transmitted in good faith: files exercising
        such insanely high compression ratios are typically payloads of buffer-
        overrun attacks, or denial-of-service (by using up too much memory)
        attacks. Consequently, files that decompress to huge sizes, particularly
        from tiny compressed forms, are best rejected as suspected malware.

        If a reply's decompressed size is bigger than this threshold (by
        default, 10 MiB, i.e. 10 * 1024 * 1024), Qt will check the compression
        ratio: if that is unreasonably large (40:1 for GZip and Deflate, or
        100:1 for Brotli and ZStandard), the reply will be treated as an error.
        Setting the threshold to `-1` disables this check.

        This function was introduced in Qt 6.2.

        **See also** **decompressedSafetyCheckThreshold** ().
        """
        ...

    def decompressedSafetyCheckThreshold(self) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#decompressedSafetyCheckThres
        hold

        **[since 6.2] qint64 QNetworkRequest::decompressedSafetyCheckThreshold()
        const**

        Returns the threshold for archive bomb checks.

        If the decompressed size of a reply is smaller than this, Qt will simply
        decompress it, without further checking.

        This function was introduced in Qt 6.2.

        **See also** **setDecompressedSafetyCheckThreshold** ().
        """
        ...

    def setTransferTimeout(self, timeout: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#setTransferTimeout

        **[since 5.15] void QNetworkRequest::setTransferTimeout(int timeout =
        DefaultTransferTimeoutConstant)**

        Sets **timeout** as the transfer timeout in milliseconds.

        Transfers are aborted if no bytes are transferred before the timeout
        expires. Zero means no timer is set. If no argument is provided, the
        timeout is **QNetworkRequest::DefaultTransferTimeoutConstant** . If this
        function is not called, the timeout is disabled and has the value zero.

        This function was introduced in Qt 5.15.

        **See also** **transferTimeout** .
        """
        ...

    def transferTimeout(self) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#transferTimeout

        **[since 5.15] int QNetworkRequest::transferTimeout() const**

        Returns the timeout used for transfers, in milliseconds.

        This timeout is zero if **setTransferTimeout**  hasn't been called,
        which means that the timeout is not used.

        This function was introduced in Qt 5.15.

        **See also** **setTransferTimeout** .
        """
        ...

    def setHttp2Configuration(self, configuration: QHttp2Configuration) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#setHttp2Configuration

        **[since 5.14] void QNetworkRequest::setHttp2Configuration(const
        QHttp2Configuration & configuration )**

        Sets request's HTTP/2 parameters from **configuration**.

        **Note:** The configuration must be set prior to making a request.

        **Note:** HTTP/2 multiplexes several streams in a single HTTP/2
        connection. This implies that **QNetworkAccessManager**  will use the
        configuration found in the first request from a series of requests sent
        to the same host.

        This function was introduced in Qt 5.14.

        **See also** **http2Configuration** , **QNetworkAccessManager** , and
        **QHttp2Configuration** .
        """
        ...

    def http2Configuration(self) -> QHttp2Configuration:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#http2Configuration

        **[since 5.14] QHttp2Configuration QNetworkRequest::http2Configuration()
        const**

        Returns the current parameters that **QNetworkAccessManager**  is using
        for this request and its underlying HTTP/2 connection. This is either a
        configuration previously set by an application or a default
        configuration.

        The default values that **QNetworkAccessManager**  is using are:

        * Window size for connection-level flowcontrol is 2147483647 octets
          *
        Window size for stream-level flowcontrol is 21474836 octets
          * Max
        frame size is 16384

        By default, server push is disabled, Huffman compression and string
        indexing are enabled.

        This function was introduced in Qt 5.14.

        **See also** **setHttp2Configuration** .
        """
        ...

    def setPeerVerifyName(self, peerName: str) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#setPeerVerifyName

        **[since 5.13] void QNetworkRequest::setPeerVerifyName(const QString &
        peerName )**

        Sets **peerName** as host name for the certificate validation, instead
        of the one used for the TCP connection.

        This function was introduced in Qt 5.13.

        **See also** **peerVerifyName** .
        """
        ...

    def peerVerifyName(self) -> str:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#peerVerifyName

        **[since 5.13] QString QNetworkRequest::peerVerifyName() const**

        Returns the host name set for the certificate validation, as set by
        **setPeerVerifyName** . By default this returns a null string.

        This function was introduced in Qt 5.13.

        **See also** **setPeerVerifyName** .
        """
        ...

    def setMaximumRedirectsAllowed(self, maximumRedirectsAllowed: int) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#setMaximumRedirectsAllowed

        **[since 5.6] void QNetworkRequest::setMaximumRedirectsAllowed(int
        maxRedirectsAllowed )**

        Sets the maximum number of redirects allowed to be followed for this
        request to **maxRedirectsAllowed**.

        This function was introduced in Qt 5.6.

        **See also** **maximumRedirectsAllowed** ().
        """
        ...

    def maximumRedirectsAllowed(self) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#maximumRedirectsAllowed

        **[since 5.6] int QNetworkRequest::maximumRedirectsAllowed() const**

        Returns the maximum number of redirects allowed to be followed for this
        request.

        This function was introduced in Qt 5.6.

        **See also** **setMaximumRedirectsAllowed** ().
        """
        ...

    def swap(self, other: "QNetworkRequest") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#swap

        **[since 5.0] void QNetworkRequest::swap(QNetworkRequest & other )**

        Swaps this network request with **other**. This function is very fast
        and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def setPriority(self, priority: "QNetworkRequest.Priority") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#setPriority

        **void QNetworkRequest::setPriority(QNetworkRequest::Priority priority
        )**

        Set the priority of this request to **priority**.

        **Note:** The **priority** is only a hint to the network access manager.
        It can use it or not. Currently it is used for HTTP to decide which
        request should be sent first to a server.

        **See also** **priority** ().
        """
        ...

    def priority(self) -> "QNetworkRequest.Priority":
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#priority

        **QNetworkRequest::Priority QNetworkRequest::priority() const**

        Return the priority of this request.

        **See also** **setPriority** ().
        """
        ...

    def originatingObject(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#originatingObject

        **QObject *QNetworkRequest::originatingObject() const**

        Returns a reference to the object that initiated this network request;
        returns `nullptr` if not set or the object has been destroyed.

        **See also** **setOriginatingObject** ().
        """
        ...

    def setOriginatingObject(self, object: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#setOriginatingObject

        **void QNetworkRequest::setOriginatingObject(QObject * object )**

        Allows setting a reference to the **object** initiating the request.

        For example Qt WebKit sets the originating object to the QWebFrame that
        initiated the request.

        **See also** **originatingObject** ().
        """
        ...

    def setSslConfiguration(self, configuration: "QSslConfiguration") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#setSslConfiguration

        **void QNetworkRequest::setSslConfiguration(const QSslConfiguration &
        config )**

        Sets this network request's SSL configuration to be **config**. The
        settings that apply are the private key, the local certificate, the SSL
        protocol (SSLv2, SSLv3, TLSv1.0 where applicable), the CA certificates
        and the ciphers that the SSL backend is allowed to use.

        **See also** **sslConfiguration** () and
        **QSslConfiguration::defaultConfiguration** ().
        """
        ...

    def sslConfiguration(self) -> "QSslConfiguration":
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#sslConfiguration

        **QSslConfiguration QNetworkRequest::sslConfiguration() const**

        Returns this network request's SSL configuration. By default this is the
        same as **QSslConfiguration::defaultConfiguration** ().

        **See also** **setSslConfiguration** () and
        **QSslConfiguration::defaultConfiguration** ().
        """
        ...

    def setAttribute(
        self, code: "QNetworkRequest.Attribute", value: typing.Any
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#setAttribute

        **void QNetworkRequest::setAttribute(QNetworkRequest::Attribute code ,
        const QVariant & value )**

        Sets the attribute associated with code **code** to be value **value**.
        If the attribute is already set, the previous value is discarded. In
        special, if **value** is an invalid **QVariant** , the attribute is
        unset.

        **See also** **attribute** () and **QNetworkRequest::Attribute** .
        """
        ...

    def attribute(
        self, code: "QNetworkRequest.Attribute", defaultValue: typing.Any = ...
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#attribute

        **QVariant QNetworkRequest::attribute(QNetworkRequest::Attribute code ,
        const QVariant & defaultValue = QVariant()) const**

        Returns the attribute associated with the code **code**. If the
        attribute has not been set, it returns **defaultValue**.

        **Note:** This function does not apply the defaults listed in
        **QNetworkRequest::Attribute** .

        **See also** **setAttribute** () and **QNetworkRequest::Attribute** .
        """
        ...

    def setRawHeader(
        self, headerName: QtCore.QByteArray, value: QtCore.QByteArray
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#setRawHeader

        **void QNetworkRequest::setRawHeader(const QByteArray & headerName ,
        const QByteArray & headerValue )**

        Sets the header **headerName** to be of value **headerValue**. If
        **headerName** corresponds to a known header (see
        **QNetworkRequest::KnownHeaders** ), the raw format will be parsed and
        the corresponding "cooked" header will be set as well.

        For example:

        request.setRawHeader(**QByteArray** ("Last-Modified"), **QByteArray**
        ("Sun, 06 Nov 1994 08:49:37 GMT"));

        will also set the known header **LastModifiedHeader**  to be the
        **QDateTime**  object of the parsed date.

        **Note:** Setting the same header twice overrides the previous setting.
        To accomplish the behaviour of multiple HTTP headers of the same name,
        you should concatenate the two values, separating them with a comma
        (",") and set one single raw header.

        **See also** **KnownHeaders** , **setHeader** (), **hasRawHeader** (),
        and **rawHeader** ().
        """
        ...

    def rawHeader(self, headerName: QtCore.QByteArray) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#rawHeader

        **QByteArray QNetworkRequest::rawHeader(const QByteArray & headerName )
        const**

        Returns the raw form of header **headerName**. If no such header is
        present, an empty **QByteArray**  is returned, which may be
        indistinguishable from a header that is present but has no content (use
        **hasRawHeader** () to find out if the header exists or not).

        Raw headers can be set with **setRawHeader** () or with **setHeader**
        ().

        **See also** **header** () and **setRawHeader** ().
        """
        ...

    def rawHeaderList(self) -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#rawHeaderList

        **QList<QByteArray> QNetworkRequest::rawHeaderList() const**

        Returns a list of all raw headers that are set in this network request.
        The list is in the order that the headers were set.

        **See also** **hasRawHeader** () and **rawHeader** ().
        """
        ...

    def hasRawHeader(self, headerName: QtCore.QByteArray) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#hasRawHeader

        **bool QNetworkRequest::hasRawHeader(const QByteArray & headerName )
        const**

        Returns `true` if the raw header **headerName** is present in this
        network request.

        **See also** **rawHeader** () and **setRawHeader** ().
        """
        ...

    def setHeader(
        self, header: "QNetworkRequest.KnownHeaders", value: typing.Any
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#setHeader

        **void QNetworkRequest::setHeader(QNetworkRequest::KnownHeaders header ,
        const QVariant & value )**

        Sets the value of the known header **header** to be **value** ,
        overriding any previously set headers. This operation also sets the
        equivalent raw HTTP header.

        **See also** **KnownHeaders** , **setRawHeader** (), and **header** ().
        """
        ...

    def header(self, header: "QNetworkRequest.KnownHeaders") -> typing.Any:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#header

        **QVariant QNetworkRequest::header(QNetworkRequest::KnownHeaders header
        ) const**

        Returns the value of the known network header **header** if it is
        present in this request. If it is not present, returns QVariant() (i.e.,
        an invalid variant).

        **See also** **KnownHeaders** , **rawHeader** (), and **setHeader** ().
        """
        ...

    def setUrl(self, url: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#setUrl

        **void QNetworkRequest::setUrl(const QUrl & url )**

        Sets the URL this network request is referring to be **url**.

        **See also** **url** ().
        """
        ...

    def url(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qnetworkrequest.html#url

        **QUrl QNetworkRequest::url() const**

        Returns the URL this network request is referring to.

        **See also** **setUrl** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QGlyphRun(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qglyphrun.html

    **Detailed Description**

    When Qt displays a string of text encoded in Unicode, it will first convert
    the Unicode points into a list of glyph indexes and a list of positions
    based on one or more fonts. The Unicode representation of the text and the
    **QFont**  object will in this case serve as a convenient abstraction that
    hides the details of what actually takes place when displaying the text on-
    screen. For instance, by the time the text actually reaches the screen, it
    may be represented by a set of fonts in addition to the one specified by the
    user, e.g. in case the originally selected font did not support all the
    writing systems contained in the text.

    Under certain circumstances, it can be useful as an application developer to
    have more low-level control over which glyphs in a specific font are drawn
    to the screen. This could for instance be the case in applications that use
    an external font engine and text shaper together with Qt. QGlyphRun provides
    an interface to the raw data needed to get text on the screen. It contains a
    list of glyph indexes, a position for each glyph and a font.

    It is the user's responsibility to ensure that the selected font actually
    contains the provided glyph indexes.

    **QTextLayout::glyphRuns** () or **QTextFragment::glyphRuns** () can be used
    to convert unicode encoded text into a list of QGlyphRun objects, and
    **QPainter::drawGlyphRun** () can be used to draw the glyphs.

    **Note:** Please note that **QRawFont**  is considered local to the thread
    in which it is constructed. This in turn means that a new **QRawFont**  will
    have to be created and set on the QGlyphRun if it is moved to a different
    thread. If the QGlyphRun contains a reference to a **QRawFont**  from a
    different thread than the current, it will not be possible to draw the
    glyphs using a **QPainter** , as the **QRawFont**  is considered invalid and
    inaccessible in this case.
    """

    class GlyphRunFlag(enum.Flag):
        Overline: QGlyphRun = ...
        Underline: QGlyphRun = ...
        StrikeOut: QGlyphRun = ...
        RightToLeft: QGlyphRun = ...
        SplitLigature: QGlyphRun = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#QGlyphRun

        **QGlyphRun::QGlyphRun()**

        Constructs an empty QGlyphRun object.
        """
        ...

    @typing.overload
    def __init__(self, other: "QGlyphRun") -> None:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#QGlyphRun-1

        **QGlyphRun::QGlyphRun(const QGlyphRun & other )**

        Constructs a QGlyphRun object which is a copy of **other**.
        """
        ...

    def swap(self, other: "QGlyphRun") -> None:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#swap

        **[since 5.0] void QGlyphRun::swap(QGlyphRun & other )**

        Swaps this glyph run instance with **other**. This function is very fast
        and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#isEmpty

        **[since 5.0] bool QGlyphRun::isEmpty() const**

        Returns `true` if the **QGlyphRun**  does not contain any glyphs.

        This function was introduced in Qt 5.0.
        """
        ...

    def boundingRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#boundingRect

        **[since 5.0] QRectF QGlyphRun::boundingRect() const**

        Returns the smallest rectangle that contains all glyphs in this
        **QGlyphRun** . If a bounding rect has been set using
        **setBoundingRect** (), then this will be returned. Otherwise the
        bounding rect will be calculated based on the font metrics of the glyphs
        in the glyph run.

        This function was introduced in Qt 5.0.

        **See also** **setBoundingRect** ().
        """
        ...

    def setBoundingRect(self, boundingRect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#setBoundingRect

        **[since 5.0] void QGlyphRun::setBoundingRect(const QRectF &
        boundingRect )**

        Sets the bounding rect of the glyphs in this **QGlyphRun**  to be
        **boundingRect**. This rectangle will be returned by **boundingRect** ()
        unless it is empty, in which case the bounding rectangle of the glyphs
        in the glyph run will be returned instead.

        **Note:** Unless you are implementing text shaping, you should not have
        to use this function. It is used specifically when the **QGlyphRun**
        should represent an area which is smaller than the area of the glyphs it
        contains. This could happen e.g. if the glyph run is retrieved by
        calling **QTextLayout::glyphRuns** () and the specified range only
        includes part of a ligature (where two or more characters are combined
        to a single glyph.) When this is the case, the bounding rect should only
        include the appropriate part of the ligature glyph, based on a
        calculation of the average width of the characters in the ligature.

        In order to support such a case (an example is selections which should
        be drawn with a different color than the main text color), it is
        necessary to clip the painting mechanism to the rectangle returned from
        **boundingRect** () to avoid drawing the entire ligature glyph.

        This function was introduced in Qt 5.0.

        **See also** **boundingRect** ().
        """
        ...

    def flags(self) -> "QGlyphRun.GlyphRunFlag":
        """
        https://doc.qt.io/qt-6/qglyphrun.html#flags

        **[since 5.0] QGlyphRun::GlyphRunFlags QGlyphRun::flags() const**

        Returns the flags set for this **QGlyphRun** .

        This function was introduced in Qt 5.0.

        **See also** **setFlags** (), **setFlag** (), and **setFlag** ().
        """
        ...

    def setFlags(self, flags: "QGlyphRun.GlyphRunFlag") -> None:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#setFlags

        **[since 5.0] void QGlyphRun::setFlags(QGlyphRun::GlyphRunFlags flags
        )**

        Sets the flags of this **QGlyphRun**  to **flags**.

        This function was introduced in Qt 5.0.

        **See also** **setFlag** () and **flags** ().
        """
        ...

    def setFlag(self, flag: "QGlyphRun.GlyphRunFlag", enabled: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#setFlag

        **[since 5.0] void QGlyphRun::setFlag(QGlyphRun::GlyphRunFlag flag ,
        bool enabled = true)**

        If **enabled** is true, then **flag** is enabled; otherwise, it is
        disabled.

        This function was introduced in Qt 5.0.

        **See also** **flags** () and **setFlags** ().
        """
        ...

    def isRightToLeft(self) -> bool:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#isRightToLeft

        **[since 5.0] bool QGlyphRun::isRightToLeft() const**

        Returns `true` if this **QGlyphRun**  contains glyphs that are painted
        from the right to the left.

        This function was introduced in Qt 5.0.

        **See also** **setRightToLeft** () and **flags** ().
        """
        ...

    def setRightToLeft(self, on: bool) -> None:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#setRightToLeft

        **[since 5.0] void QGlyphRun::setRightToLeft(bool rightToLeft )**

        Indicates that this **QGlyphRun**  contains glyphs that should be
        ordered from the right to left if **rightToLeft** is true. Otherwise the
        order of the glyphs is assumed to be left to right.

        This function was introduced in Qt 5.0.

        **See also** **isRightToLeft** (), **setFlag** (), and **setFlags** ().
        """
        ...

    def strikeOut(self) -> bool:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#strikeOut

        **bool QGlyphRun::strikeOut() const**

        Returns `true` if this **QGlyphRun**  should be painted with a strike
        out decoration.

        **See also** **setStrikeOut** () and **flags** ().
        """
        ...

    def setStrikeOut(self, strikeOut: bool) -> None:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#setStrikeOut

        **void QGlyphRun::setStrikeOut(bool strikeOut )**

        Indicates that this **QGlyphRun**  should be painted with an strike out
        decoration if **strikeOut** is true. Otherwise the **QGlyphRun**  should
        be painted with no strike out decoration.

        **See also** **strikeOut** (), **setFlag** (), and **setFlags** ().
        """
        ...

    def underline(self) -> bool:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#underline

        **bool QGlyphRun::underline() const**

        Returns `true` if this **QGlyphRun**  should be painted with an
        underline decoration.

        **See also** **setUnderline** () and **flags** ().
        """
        ...

    def setUnderline(self, underline: bool) -> None:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#setUnderline

        **void QGlyphRun::setUnderline(bool underline )**

        Indicates that this **QGlyphRun**  should be painted with an underline
        decoration if **underline** is true. Otherwise the **QGlyphRun**  should
        be painted with no underline decoration.

        **See also** **underline** (), **setFlag** (), and **setFlags** ().
        """
        ...

    def overline(self) -> bool:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#overline

        **bool QGlyphRun::overline() const**

        Returns `true` if this **QGlyphRun**  should be painted with an overline
        decoration.

        **See also** **setOverline** () and **flags** ().
        """
        ...

    def setOverline(self, overline: bool) -> None:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#setOverline

        **void QGlyphRun::setOverline(bool overline )**

        Indicates that this **QGlyphRun**  should be painted with an overline
        decoration if **overline** is true. Otherwise the **QGlyphRun**  should
        be painted with no overline decoration.

        **See also** **overline** (), **setFlag** (), and **setFlags** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#clear

        **void QGlyphRun::clear()**

        Clears all data in the **QGlyphRun**  object.
        """
        ...

    def setPositions(self, positions: typing.Iterable[QtCore.QPointF]) -> None:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#setPositions

        **void QGlyphRun::setPositions(const QList<QPointF> & positions )**

        Sets the positions of the edge of the baseline for each glyph in this
        set of glyph indexes to **positions**.

        **See also** **positions** ().
        """
        ...

    def positions(self) -> typing.List[QtCore.QPointF]:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#positions

        **QList<QPointF> QGlyphRun::positions() const**

        Returns the position of the edge of the baseline for each glyph in this
        set of glyph indexes.

        **See also** **setPositions** ().
        """
        ...

    def setGlyphIndexes(self, glyphIndexes: typing.Iterable[int]) -> None:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#setGlyphIndexes

        **void QGlyphRun::setGlyphIndexes(const QList<quint32> & glyphIndexes
        )**

        Set the glyph indexes for this **QGlyphRun**  object to
        **glyphIndexes**. The glyph indexes must be valid for the selected font.

        **See also** **glyphIndexes** ().
        """
        ...

    def glyphIndexes(self) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#glyphIndexes

        **QList<quint32> QGlyphRun::glyphIndexes() const**

        Returns the glyph indexes for this **QGlyphRun**  object.

        **See also** **setGlyphIndexes** () and **setPositions** ().
        """
        ...

    def setRawFont(self, rawFont: "QRawFont") -> None:
        """
        https://doc.qt.io/qt-6/qglyphrun.html#setRawFont

        **void QGlyphRun::setRawFont(const QRawFont & rawFont )**

        Sets the font in which to look up the glyph indexes to the **rawFont**
        specified.

        **See also** **rawFont** () and **setGlyphIndexes** ().
        """
        ...

    def rawFont(self) -> "QRawFont":
        """
        https://doc.qt.io/qt-6/qglyphrun.html#rawFont

        **QRawFont QGlyphRun::rawFont() const**

        Returns the font selected for this **QGlyphRun**  object.

        **See also** **setRawFont** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QSignalBlocker(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsignalblocker.html

    **Detailed Description**

    QSignalBlocker can be used wherever you would otherwise use a pair of calls
    to blockSignals(). It blocks signals in its constructor and in the
    destructor it resets the state to what it was before the constructor ran.

    {
        const **QSignalBlocker**  blocker(someQObject);
        // no signals here
    }

    is thus equivalent to

    const bool wasBlocked = someQObject->blockSignals(true);
        // no signals
    here
        someQObject->blockSignals(wasBlocked);

    except the code using QSignalBlocker is safe in the face of exceptions.

    **See also** **QMutexLocker**  and **QEventLoopLocker** .
    """

    def __init__(self, o: QObject) -> None:
        """
        https://doc.qt.io/qt-6/qsignalblocker.html#QSignalBlocker

        **QSignalBlocker::QSignalBlocker(QObject * object )**

        Constructor. Calls **object** ->blockSignals(true).
        """
        ...

    def __exit__(
        self, type: typing.Any, value: typing.Any, traceback: typing.Any
    ) -> None:
        ...

    def __enter__(self) -> typing.Any:
        ...

    def unblock(self) -> None:
        """
        https://doc.qt.io/qt-6/qsignalblocker.html#unblock

        **void QSignalBlocker::unblock()**

        Temporarily restores the **QObject::signalsBlocked** () state to what it
        was before this **QSignalBlocker** 's constructor ran. To undo, use
        **reblock** ().

        The numbers of **reblock** () and unblock() calls are not counted, so
        every unblock() undoes any number of **reblock** () calls.
        """
        ...

    def reblock(self) -> None:
        """
        https://doc.qt.io/qt-6/qsignalblocker.html#reblock

        **void QSignalBlocker::reblock()**

        Re-blocks signals after a previous **unblock** ().

        The numbers of reblock() and **unblock** () calls are not counted, so
        every reblock() undoes any number of **unblock** () calls.
        """
        ...
